/*exported log, toBe, not, greater, numeric_limits, roughly, less, toBeGreater, toBeLess, TestTimer, File, wait, getDictKeyFromValue, randomInIndex, randomIntBetween, createDir, TOLERANCE, randomNumberBetween, percentDifferenceBetween, boundAngle, imageResize, compareCurrentCanvasToSavedImage, fullSceneRenderTime,
getSystemFontFamilies, randomPropertyFromObject, showDialogBox */
/*global print, ScriptHelper, ImageAndFilesInfo, GPCanvasModel */

var TOLERANCE = 0.1; // The tolerance used for rough comparisons


// A list of numbers that can be used for testing validation and such
var numeric_limits = [
    Number.MAX_VALUE,
    -Number.MAX_VALUE,
    Number.MIN_VALUE,
    -Number.MIN_VALUE,
    NaN,
    Number.NEGATIVE_INFINITY,
    Number.POSITIVE_INFINITY
];

var date = new Date();
var globalRNG = new Math.seedrandom(date); // This is the seed for the RNG used for all tests

var TEMPIMAGE = 'results/imageCompare/last_comp.png'; // The image that all image comparisons use

/**
 * Function that returns the percente difference between two numbers
 * @param   {Number} result   One input
 * @param   {Number} expected The other input
 * @returns {Number} The percent difference between the two inputs
 */
function percentDifferenceBetween(result, expected) {
    if((result.constructor !== Number) || (expected.constructor !== Number)) {
        throw new Error('Cannot get the percent difference of something that is not a number');
    }
    return Math.abs(100 * ((expected - result) / expected));
}

/**
 * Function that prints result and expected to console
 * @param   {Object}  result   Result of a test to be compared
 * @param   {Object}  expected Variable to compare result against
 * @returns {Boolean} Alway returns true so tests will keep running
 */
function log(result, expected) {
    print('Result: ' + result + ' Expected: ' + expected);
    return true;
}

/**
 * Function to assert that the inputs are equal
 * @param   {Object}  result   Result of a test to be compared
 * @param   {Object}  expected Variable to compare result against
 * @returns {Boolean} The result of the comparison
 */
function toBe(result, expected) {
    var resultType = typeof result;
    var expectedType = typeof expected;
    if(resultType === 'undefined' || expectedType === 'undefined')
    {
        if(resultType === expectedType) {
            return true;
        } else {
            return false;
        }
    }
    
    if(result.constructor !== expected.constructor) {
        return false;
    }
    
    if(result.constructor === Number){
        if ( (isNaN(result) && isNaN(expected)) || (!isFinite(result) && !isFinite(expected)) ) {
            return true;
        }
    }
    
    // Return true if two arrays were passed in that have identical contents and length
    if ((expected.constructor === Array) && (result.constructor === Array)) {
        if (result.length !== expected.length) {
            
            // If the lengths differ
            return false;
        }
        for (var i = 0; i < expected.length; i++) {
            if (result[i] !== expected[i]) {
                
                // If any item differs
                return false;
            }
        }
        
        // All items were the same in the array
        return true;
    } else {
        
        // If both inputs are finite, not NaN, and not arrays, return the comparison between the two
        return result === expected;
    }
}

/**
 * Function to assert that the two inputs are within a certain decimal amount of each other
 * @param   {Number}  result   Result of a test to be compared
 * @param   {Number}  expected Variable to compare result against
 * @returns {Boolean} The result of the comparison
 */
function roughly(result, expected) {
    if ((result.constructor !== Number) || (expected.constructor !== Number)) {
        throw new Error('The "roughly" comparison only takes numbers');
    } else if ((result === expected) || (isNaN(result) && isNaN(expected))) {
        return true;
    } else if (isNaN(result) || isNaN(expected) || !isFinite(result) || !isFinite(expected)) {
        print('DEBUG: One argument to the roughly comparison was either a NaN or infinite\n' +
             'Result: "' + result + '", isNaN: "' + isNaN(result) + '", isFinite: "' + isFinite(result) + '".\n' + 
             'Expected: "' + expected + '", isNaN: "' + isNaN(expected) + '", isFinite: "' + isFinite(expected) + '".');
        return false;
    }

    var difference = Math.abs(result - expected);

    if (difference > TOLERANCE) {
        return false;
    } else {
        return true;
    }
}

/**
 * Function to assert that the inputs are NOT equal
 * @param   {Object}  result   Result of a test to be compared
 * @param   {Object}  expected Variable to compare result against
 * @returns {Boolean} The result of the comparison
 */
function not(result, expected) {
    if ((expected.constructor === Array) && (result.constructor === Array)) {
        if (result.length !== expected.length) {
            return true;
        }
        for (var i = 0; i < expected.length; i++) {
            if (result[i] !== expected[i]) {
                return true;
            }
        }
        return false;
    }

    return result !== expected;
}

/**
 * Function to assert that the result is GREATER than the expected value
 * @param   {Object}  result   Result of a test to be compared
 * @param   {Object}  expected Variable to compare result against
 * @returns {Boolean} The result of the comparison
 */
function greater(result, expected) {
    if((result.constructor !== Number) || (expected.constructor !== Number)) {
        throw new Error('Cannot compare size of something that is not a number');
    }
    return result > expected;
}

/**
 * Function to assert that the result is LESS than the expected value
 * @param   {Object} result   Result of a test to be compared
 * @param   {Object} expected Variable to compare result against
 * @returns {Number} The result of the comparison
 */
function less(result, expected) {
    if((result.constructor !== Number) || (expected.constructor !== Number)) {
        throw new Error('Cannot compare size of something that is not a number');
    }
    return result < expected;
}

/**
 * Function to assert that the result is GREATER THAN OR EQUAL TO the expected value
 * @param   {Object}  result   Result of a test to be compared
 * @param   {Object}  expected Variable to compare result against
 * @returns {Boolean} The result of the comparison
 */
function toBeGreater(result, expected) {
    if((result.constructor !== Number) || (expected.constructor !== Number)) {
        throw new Error('Cannot compare size of something that is not a number');
    }
    return result >= expected;
}

/**
 * Function to assert that the result is LESS THAN OR EQUAL TO the expected value
 * @param   {Object}  result   Result of a test to be compared
 * @param   {Object}  expected Variable to compare result against
 * @returns {Boolean} The result of the comparison
 */
function toBeLess(result, expected) {
    if((result.constructor !== Number) || (expected.constructor !== Number)) {
        throw new Error('Cannot compare size of something that is not a number');
    }
    return result <= expected;
}

/**
 * An object used for various timing functions
 */
function TestTimer() {
    this.time = 0;
    var startTime = 0;
    var stopTime = 0;
    this.startDate = null;
    this.stopDate = null;

    /**
     * Start the timer used for performance testing
     */
    this.startTimer = function () {
        this.startDate = new Date();
        startTime = this.startDate.getTime();
    };

    /**
     * Stop timer, set time, and set average
     */
    this.stopTimer = function () {
        this.stopDate = new Date();
        stopTime = this.stopDate.getTime();
        this.time = stopTime - startTime;
        startTime = 0;
        stopTime = 0;
    };

    /**
     * Run a function and return the total run time
     * @param  {Function} func The function to run
     * @return {Number} the time taken by the function
     */
    this.getTime = function (func, arg) {
        if (func.constructor !== Function) {
            throw new Error('The "TestTimer.getTime" function only takes a function as input');
        }
        this.startTimer();
        func(arg);
        this.stopTimer();
        return this.time;
    };

    /**
     * Run a function multiple times and return the average time
     * @param  {Function} func The function to run
     * @param  {Number} count The number of times to run the function
     * @returns {Number} the time taken by the function on average
     */
    this.getAverageTime = function (func, count, arg) {
        if (func.constructor !== Function) {
            throw new Error('The "TestTimer.getAverageTime" function only takes a String for the "func" argument');
        } else if (count.constructor !== Number) {
            throw new Error('The "TestTimer.getAverageTime" function only takes a Number for the "count" argument');
        }
        this.startTimer();
        for (var i = 0; i < count; i++) {
            func(arg);
        }
        this.stopTimer();
        var average = this.time / count;
        return average;
    };
}

/**
 * An object used for writing to files
 * @param {String}  file      The file path
 * @param {Boolean} overwrite True to overwrite the file, false to append
 */
function File(file, overwrite) {
    if (file.constructor !== String) {
        throw new Error('The "File" constructor only takes a String for the "file" argument');
    }
    this.file = file;
    var doOverwrite = false;
    if (typeof overwrite !== 'undefined') {
        if (overwrite.constructor !== Boolean) {
            throw new Error('The "File" constructor only takes a Boolean for the "overwrite" argument');
        } else {
            doOverwrite = overwrite;
        }
    }

    /**
     * Funciton to write data to the file
     * @param {String}  str        The data to be written
     * @param {Boolean} testPassed Whether to signal that this is a passed test
     */
    this.write = function (str, testPassed) {
        if (typeof testPassed === 'undefined') {
            testPassed = true;
        } else if (testPassed.constructor !== Boolean) {
            throw new Error('The "File.write" function only takes a Boolean for the "testPassed" argument');
        }
        if (str.constructor !== String) {
            throw new Error('The "File.write" function only takes a String for the "str" argument');
        }
        ScriptHelper.write(this.file, str, testPassed, doOverwrite);
    };
}

/**
 * Wait for the specified time
 * @param  {Number} ms Wait for this many milliseconds
 */
function wait(ms) {
    if (ms.constructor !== Number) {
            throw new Error('The "wait" function only takes a Number for the "ms" argument');
        }
    var d = new Date();
    var d2 = null;

    do {
        d2 = new Date();
    }
    while (d2 - d < ms);
}

/**
 * Function to get the key associated with a value in a dictionary
 * @param {Object} dict - The dictionary
 * @param {Object} value - The value
 * @returns {Object} The key that was found, or undefined if none was found
 */
function getDictKeyFromValue(dict, value) {
    for (var key in dict) {
        if (dict[key] === value) {
            return key;
        }
    }
    return undefined;
}

/**
 * Function to pick a random item from an array and return it
 * @param   {Array}  inputList The array to pick from
 * @returns {Object} The randomly selected item
 */
function randomInIndex(inputList) {
    var listLength = inputList.length;
    var randIndex = Math.floor(globalRNG() * listLength);
    var returnVal = inputList[randIndex];
    return returnVal;
}

/**
 * Picks a random property of an object
 * @param   {Object} object Object to pick a property from
 * @returns {Object} Randomly selected property
 */
function randomPropertyFromObject(object) {
    var listOfKeys = [];
    for(var key in object) {
        if(object.hasOwnProperty(key) && key !== 'undefined') {
            listOfKeys.push(key);
        }
    }
    return randomInIndex(listOfKeys);
}

/**
 * Function to return an integer between two values
 * @param   {Number} low  The lowest value
 * @param   {Number} high The highest value
 * @returns {Number} A random number between and including the two input values
 */
function randomIntBetween(low, high) {
    if ((low.constructor !== Number) || (high.constructor !== Number)) {
        throw new Error('The "randomIntBetween" function only takes numbers');
    }
    return Math.floor(globalRNG() * (high - low + 1) + low);
}

/**
 * Function to return a number between two values
 * @param   {Number} low  The lowest value
 * @param   {Number} high The highest value
 * @returns {Number} A random number between and including the two input values
 */
function randomNumberBetween(low, high) {
    if ((low.constructor !== Number) || (high.constructor !== Number)) {
        throw new Error('The "randomIntBetween" function only takes numbers');
    }
    return low + (globalRNG() * (high - low));
}

/**
 * Creates a directory from the given path
 * @param   {String}  dirPath The directory to create
 */
function createDir(dirPath) {
    if (dirPath.constructor !== String) {
        throw new Error('The "createDir" function only takes a String');
    } else if(dirPath === '') {
        return;
    }
    var result = ScriptHelper.createDir(dirPath);
    if(!result) {
        throw new Error('Could not create directory "' + dirPath + '"');
    }
}

/**
 * Creates a list of files in the given path
 * @throws {Error} [[Description]]
 * @param   {string} dirPath The directory to search
 * @param   {string} filter  filters the results
 * @returns {Array}  List of all files in directory
 */
function listFiles(dirPath, filter) {
    debugger;
    if (dirPath.constructor !== String) {
        throw new Error('The "listFiles" function only takes a String');
    } else if(dirPath === '') {
        return;
    }
    var filesList = ScriptHelper.getFiles(dirPath, filter);
    return filesList;
}

/**
 * Bounds an angle between 0 and 360
 * @param {Number} angle The angle to bound
 */
function boundAngle(angle) {
    return ((angle % 360) + 360) % 360;
}

/**
 * Returns the average time it took to render the scene over a given number of iterations
 * @param   {Number} iterations The number of iterations to render
 * @returns {Number} The time it took to render, in milliseconds
 */
function fullSceneRenderTime(iterations) {
    
    // Will default to one iteration if no arguments are passed
    var iters = 1;
    
    // Validate the input
    if(typeof iterations !== 'undefined') {
        if(iterations.constructor === Number) {
            if(iterations >= 1) {
                iters = iterations;
            } else {
                throw new Error('iterations must be 1 or more');
            }
        } else {
            throw new Error('iterations must be a number');
        }
    }
    
    return ScriptHelper.fullSceneRenderTime(GPCanvasModel, iters);
}

/**
 * Saves a screenshot of the given coordinates in the canvas
 * @param {String} imagePath The path to save the image to
 * @param {Number} x         The X-Coordinate of the top left corner of the screenshot
 * @param {Number} y         The Y-Coordinate of the top left corner
 * @param {Number} w         The width of the screenshot
 * @param {Number} h         The height of the screenshot
 */
function saveScreenshot(imagePath, x, y, w, h) {
    
    // Create the directory to save the image in
    createDir(imagePath.substring(0, imagePath.lastIndexOf('/')));
    var result;
    
    if((typeof x !== 'undefined') && (x.constructor === Number) &&
      (typeof y !== 'undefined') && (y.constructor === Number) &&
      (typeof w !== 'undefined') && (w.constructor === Number) &&
      (typeof h !== 'undefined') && (h.constructor === Number)) {
       result = ScriptHelper.saveScreenShot(GPCanvasModel, imagePath, x, y, w, h);
    } else {
        result = ScriptHelper.saveScreenShot(GPCanvasModel, imagePath);
    }
    
    
    if(!result) {
        throw new Error('Could not save image to "' + imagePath + '"');
    }
}

/**
 * Resize an image to the same dimensions of another
 * @param {string} name1 file 1's name
 * @param {string} name2 file 2's name 
 */
function imageResize(name1, name2){
    ScriptHelper.imageResize(name1, name2);
    return;
}


/**
 * Returns the difference between the current canvas and a saved image
 * @param   {String} imagePath The path to the saved image
 * @param   {Number} x         The X-Coordinate of the top left corner of the section of the canvas to check
 * @param   {Number} y         The Y-Cordinate of the top left corner
 * @param   {Number} w         The width of the checked area
 * @param   {Number} h         The height of the checked area
 * @returns {Number} The difference, between 0 and 1
 */
function compareCurrentCanvasToSavedImage(imagePath, x, y, w, h) {
    
    // Save a temporary screenshot to use for the comparison
    saveScreenshot(TEMPIMAGE, x, y, w, h);
    
    var returnVal;
    
    if((typeof x !== 'undefined') && (x.constructor === Number) &&
      (typeof y !== 'undefined') && (y.constructor === Number) &&
      (typeof w !== 'undefined') && (w.constructor === Number) &&
      (typeof h !== 'undefined') && (h.constructor === Number)) {
       returnVal = ScriptHelper.compareSavedImages(TEMPIMAGE, imagePath, x, y, w, h);
    } else {
        returnVal = ScriptHelper.compareSavedImages(TEMPIMAGE, imagePath);
    }
    
    return returnVal;
}

function getSystemFontFamilies() {
    return ScriptHelper.getSystemFontFamilies();
}
