/* globals EllyModel, GPCanvasModel */


/**
 * Add barcode to canvas with preset properties
 * @param {Number}  x        Starting X coordinate
 * @param {Number}  y        Starting Y coordinate
 * @param {Number}  rotation Starting rotation in degrees
 * @param {Boolean} selected Enable/disbale selection after adding
 * @param {Number}  width    Initial width
 * @param {Number}  height   Initial height
 * @param {Number}  symbol   Initial symbol
 * @param {Number}  option2  Check Digit for Code39 and columns for PDF417
 * @param {String}  text     Initial Barcode text
 * @param {String}  color    Initial Barcode color
 * @param {String}  bgcolor  Initial Barcode background color
 */
EllyModel.prototype.addBarcodeItem = function (x, y, rotation, selected, width, height, symbol, option2, text, color, bgcolor) {
    
    var setX, setY, setRotation, setSelected, setWidth, setHeight, setAspectRatio, setSymbol, setOption2, setText, setColor, setBgColor;
    
    if (typeof x === 'undefined') {
        throw new Error('x is not an optional parameter');
    } else if (x.constructor !== Number) {
        throw new TypeError('x must be of the type "Number"');
    } else {
        setX = x;
    }

    if (y.constructor !== Number) {
        throw new TypeError('y must be of the type "Number"');
    } else if (typeof y === 'undefined') {
        throw new Error('y is not an optional parameter');
    } else {
        setY = y;
    }

    if(typeof rotation === 'undefined') {
        throw new Error('rotation is not an optional parameter');
    } else if(rotation.constructor !== Number) {
        throw new TypeError('rotation must be of the type "Number"');
    } else {
        setRotation = rotation;
    }

    if (typeof selected === 'undefined') {
        setSelected = false;
    } else if (selected.constructor !== Boolean) {
        throw new TypeError('selected must be of the type "Boolean"');
    } else {
        setSelected = selected;
    }

    if (typeof width === 'undefined') {
        setWidth = 0;
    } else if (width.constructor !== Number) {
        throw new TypeError('width must be of the type "Number"');
    } else {
        setWidth = width;
    }

    if (typeof height === 'undefined') {
        setHeight = 0;
    } else if(height.constructor !== Number) {
        throw new TypeError('height must be of the type "Number"');
    } else {
        setHeight = height;
    }

    if (typeof symbol === 'undefined') {
        setSymbol = 0;
    } else if(symbol.constructor !== Number) {
        throw new TypeError('symbol must be of the type "Number"');
    } else {
        setSymbol = symbol;
    }

    if(typeof option2 === 'undefined') {
        setOption2 = 0;
    } else if(option2.constructor !== Number) {
        throw new TypeError('option2 must be of the type "Number"');
    } else {
        setOption2 = option2;
    }
    
    if(typeof text === 'undefined') {
        setText = '';
    } else if(text.constructor !== String) {
        throw new TypeError('text must be of the type "String"');
    } else {
        setText = text;
    }
    
    if(typeof color === 'undefined') {
        setColor = '';
    } else if(color.constructor !== String) {
        throw new TypeError('color must be of the type "String"');
    } else {
        setColor = color;
    }
    
    if(typeof bgcolor === 'undefined') {
        setBgColor = '';
    } else if(bgcolor.constructor !== String) {
        throw new TypeError('bgcolor must be of the type "String"');
    } else {
        setBgColor = bgcolor;
    }
    
    var GenericInsertOptions = {positionX: setX, positionY: setY, rotationDegrees: setRotation, initiallySelected: setSelected, itemW: setWidth, itemH: setHeight, aspectRatio: setAspectRatio};
    
    var BarcodeInsertOptions = {symbol: setSymbol, option2: setOption2, text: setText, color: setColor, bgcolor: setBgColor};
    
    InsertController.insertBarcode(GenericInsertOptions, BarcodeInsertOptions);
    
    //GPCanvasModel.addBarcodeItem(x, y, rotation, selected, width, height);
};
