/* globals EllyModel, InsertController */


/**
 * Add an svg or image to the canvas
 * @param {String}  fileName    required; if invalid, the item will not be created
 * @param {Number}  X           X Position - required
 * @param {Number}  Y           Y Position - required
 * @param {Number}  rotation    Rotation - required
 * @param {Boolean} selected    Start selected
 * @param {Number}  width       Item width
 * @param {Number}  height      Item height
 * @param {Boolean} aspectRatio Enable/disable keeping aspect ratio                          
 * @param {String}  color       If the file is a mono SVG, this is the color to change it to   
 */
EllyModel.prototype.addGraphicItem = function (fileName, X, Y, rotation, selected, width, height, aspectRatio) {
    var setWidth = 0;
    var setHeight = 0;

    if (typeof fileName !== 'undefined') {
        if (fileName.constructor !== String) {
            throw new Error('File name must be a string');
        }
    } else {
        throw new Error('File name is a required argument');
    }
    if (typeof X !== 'undefined') {
        if (X.constructor !== Number) {
            throw new Error('X position must be a number');
        }
    } else {
        throw new Error('X position is a required argument');
    }
    if (typeof Y !== 'undefined') {
        if (Y.constructor !== Number) {
            throw new Error('Y position must be a number');
        }
    } else {
        throw new Error('Y position is a required argument');
    }
    if (typeof rotation !== 'undefined') {
        if (rotation.constructor !== Number) {
            throw new Error('Rotation must be a number');
        }
    } else {
        throw new Error('Rotation is a required argument');
    }
    if (typeof selected !== 'undefined') {
        if (selected.constructor !== Boolean) {
            throw new Error('Selection flag must be a boolean');
        }
    }
    if (typeof width !== 'undefined') {
        if (width.constructor !== Number) {
            throw new Error('Width must be a number');
        } else {
            setWidth = width;
        }
    }
    if (typeof height !== 'undefined') {
        if (height.constructor !== Number) {
            throw new Error('Height must be a number');
        } else {
            setHeight = height;
        }
    }
    if (typeof aspectRatio !== 'undefined') {
        if (aspectRatio.constructor !== Number) {
            throw new Error('Aspect ratio flag must be 0 or 1');
        }
    }
    
    var GenericInsertOptions = {positionX: X, positionY: Y, rotationDegrees: rotation, initiallySelected: selected, itemW: setWidth, itemH: setHeight, aspectRatio: aspectRatio};
    
    InsertController.insertGraphic(GenericInsertOptions, fileName);

    //GPCanvasModel.addGraphicItem(fileName, X, Y, rotation, selected, setWidth, setHeight, aspectRatio);
};