/* globals EllyModel, InsertController */


/**
 * Adds a line to the canvas via its points
 * @param {Number}  p1x             Point 1's x
 * @param {Number}  p1y             Point 1's y
 * @param {Number}  p2x             Point 2's x
 * @param {Number}  p2y             Point 2's y
 * @param {Boolean} select          Start selected or not
 * @param {String}  penColor        Pen Color
 * @param {Number}  penWidth        Pen Width
 * @param {String}  penStyle        Pen Style
 * @param {String}  penCapStyle     Pen Cap Style
 * @param {String}  penJoinStyle    Pen Join Style
 * @param {String}  leftArrowStyle  Left Arrow's style
 * @param {String}  rightArrowStyle Right Arrow's Style
 */
EllyModel.prototype.addLineByPoints = function (p1x, p1y, p2x, p2y, select, penColor, penWidth, penStyle, penCapStyle, penJoinStyle, leftArrowStyle, rightArrowStyle) {

    var set_p1x, set_p1y, set_p2x, set_p2y, setSelect, setPenColor, setPenWidth, setPenStyle,
        setPenCapStyle, setPenJoinStyle, setLeftArrowStyle, setRightArrowStyle;

    if(typeof p1x === 'undefined') {
        throw new Error('p1x is a required argument');
    } else if(p1x.constructor !== Number) {
        throw new TypeError('p1x must be of type "Number"');
    } else {
        set_p1x = p1x;
    }

    if(typeof p1y === 'undefined') {
        throw new Error('p1y is a required argument');
    } else if(p1y.constructor !== Number) {
        throw new TypeError('p1y must be of type "Number"');
    } else {
        set_p1y = p1y;
    }

    if(typeof p2x === 'undefined') {
        throw new Error('p2x is a required argument');
    } else if(p2x.constructor !== Number) {
        throw new TypeError('p2x must be of type "Number"');
    } else {
        set_p2x = p2x;
    }

    if(typeof p2y === 'undefined') {
        throw new Error('p2y is a required argument');
    } else if(p2y.constructor !== Number) {
        throw new TypeError('p2y must be of type "Number"');
    } else {
        set_p2y = p2y;
    }

    if(typeof select === 'undefined') {
        setSelect = false;
    } else if(select.constructor !== Boolean) {
        throw new TypeError('select must be of type "Boolean"');
    } else {
        setSelect = select;
    }

    if(typeof penColor === 'undefined') {
        setPenColor = '';
    } else if(penColor.constructor !== String) {
        throw new TypeError('penColor must be of the type "String"');
    } else {
        setPenColor = penColor;
    }

    if(typeof penWidth === 'undefined') {
        setPenWidth = 10;
    } else if(penWidth.constructor !== Number) {
        throw new TypeError('penWidth must be of the type "Number"');
    } else {
        setPenWidth = penWidth;
    }

    if(typeof penStyle === 'undefined') {
        setPenStyle = this.lstPenStyles.SolidLine;
    } else if(penStyle.constructor !== String) {
        throw new TypeError('penStyle must be of the type "String"');
    } else {
        setPenStyle = this.lstPenStyles[penStyle];
        if(typeof setPenStyle === 'undefined') {
            throw new Error('Invalid pen style "' + penStyle + '"');
        }
    }

    if(typeof penCapStyle === 'undefined') {
        setPenCapStyle = this.lstCapStyles.Round;
    } else if(penCapStyle.constructor !== String) {
        throw new TypeError('penCapStyle must be of the type "String"');
    } else {
        setPenCapStyle = this.lstCapStyles[penCapStyle];
        if(typeof setPenCapStyle === 'undefined') {
            throw new Error('Invalid pen cap style "' + penCapStyle + '"');
        }
    }

    if(typeof penJoinStyle === 'undefined') {
        setPenJoinStyle = this.lstJoinStyles.Round;
    } else if(penJoinStyle.constructor !== String) {
        throw new TypeError('penJoinStyle must be of the type "String"');
    } else {
        setPenJoinStyle = this.lstJoinStyles[penJoinStyle];
        if(typeof setPenJoinStyle === 'undefined') {
            throw new Error('Invalid pen join style "' + penJoinStyle + '"');
        }
    }

    if(typeof leftArrowStyle === 'undefined') {
        setLeftArrowStyle = this.lstLeftArrowTypes.NoArrow;
    } else if(leftArrowStyle.constructor !== String) {
        throw new TypeError('leftArrowStyle must be of type "String"');
    } else {
        setLeftArrowStyle = this.lstLeftArrowTypes[leftArrowStyle];
        if(typeof setLeftArrowStyle === 'undefined') {
            throw new Error('Invalid Line Left Arrow Style "' + leftArrowStyle + '"');
        }

    }

    if(typeof rightArrowStyle === 'undefined') {
        setRightArrowStyle = this.lstRightArrowTypes.NoArrow;
    } else if(rightArrowStyle.constructor !== String) {
        throw new TypeError('rightArrowStyle must be of type "String"');
    } else {
        setRightArrowStyle = this.lstRightArrowTypes[rightArrowStyle];
        if(typeof setRightArrowStyle === 'undefined') {
            throw new Error('Invalid Line Right Arrow Style "' + rightArrowStyle + '"');
        }

    }
    
    // Need to create the necessary structs for the InsertController
    var LineInsertOptions = {initiallySelected: setSelect, arrowStyleLeft: setLeftArrowStyle, arrowStyleRight: setRightArrowStyle};
    var PenInsertOptions = {penColor: setPenColor, penWidth: setPenWidth, penStyle: setPenStyle, penCapStyle: setPenCapStyle, penJoinStyle: setPenJoinStyle};
    
    InsertController.insertLineByPoints(set_p1x, set_p1y, set_p2x, set_p2y, LineInsertOptions, PenInsertOptions);

    /*GPCanvasModel.addLineItem(set_p1x, set_p1y, set_p2x,set_p2y, set_select, set_penColor,
                                set_penWidth, set_penStyle, set_penCapStyle, set_penJoinStyle,
                                set_leftArrowStyle, set_rightArrowStyle);*/
};
    