/* globals EllyModel, InsertController */

/**
 * Add a pixmap item to canvas with specified initial properties
 * @param {String}  fileName    Image file location
 * @param {Number}  x           Starting X coordinate
 * @param {Number}  y           Starting Y coordinate
 * @param {Number}  rotation    Starting rotation in degrees
 * @param {Boolean} selected    Enable/disbale selection on creation
 * @param {Number}  width       Initial width
 * @param {Number}  height      Initial height
 * @param {Boolean} aspectRatio Enable/disable keeping aspect ratio  
 */
EllyModel.prototype.addPixmapItem = function(fileName, x, y, rotation, selected, width, height, aspectRatio) {
    //fileName, x, y, rotation, selected, width, height, aspectRatio);
    
    var setX, setY, setRotation, setSelected, setWidth, setHeight, setAspectRatio;
    
    if (x.constructor !== Number) {
        throw new TypeError('x must be of the type "Number"');
    } else if (typeof x === 'undefined') {
        setX = 0;
    } else {
        setX = x;
    }
    
    if(y.constructor !== Number) {
        throw new TypeError('y must be of the type "Number"');
    } else if(typeof y === 'undefined') {
        setY = 0;
    } else {
        setY = y;
    }
    
    if(rotation.constructor !== Number) {
        throw new TypeError('rotation must be of the type "Number"');
    } else if(typeof rotation === 'undefined') {
        setRotation = 0;
    } else {
        setRotation = rotation;
    }
    
    if(typeof selected === 'undefined') {
        setSelected = true;
    } else if(selected.constructor !== Boolean) {
        throw new TypeError('selected must be of the type "Boolean"');
    } else {
        setSelected = selected;
    }
    
    if(typeof width === 'undefined') {
        setWidth = 0;
    } else if(width.constructor !== Number) {
        throw new TypeError('width must be of the type "Number"');
    } else {
        setWidth = width;
    }

    if(typeof height === 'undefined') {
        setHeight = 0;
    } else if(height.constructor !== Number) {
        throw new TypeError('height must be of the type "Number"');
    } else {
        setHeight = height;
    }

    if(typeof aspectRatio === 'undefined') {
        setAspectRatio = false;
    } else if(selected.constructor !== Boolean) {
        throw new TypeError('Aspect ratio must be of the type "Boolean"');
    } else {
        setAspectRatio = aspectRatio;
    }
    
    // Need to create the necessary structs for the InsertController
    var GenericInsertOptions = {positionX: setX, positionY: setY, rotationDegrees: setRotation, initiallySelected: setSelected, itemW: setWidth, itemH: setHeight, aspectRatio: setAspectRatio};
    
    InsertController.insertPixmap(GenericInsertOptions, fileName);
    //GPCanvasModel.addPixmapItem(fileName, x, y, rotation, selected, width, height, aspectRatio);
};