/* globals EllyModel, InsertController */

/**
 * adds a simple shape item to the collection/canvas
 * @param {String}  shape        a simple shape type from enumeration
 * @param {Number}  x            Initial X position
 * @param {Number}  y            Initial Y position
 * @param {Number}  rotation     Initial Rotation
 * @param {Boolean} selected     Initially Selected
 * @param {Number}  width        Initial Width
 * @param {Number}  height       Initial Height
 * @param {Boolean} aspectRatio  Enable/disable keeping aspect ratio
 * @param {String}  penColor     Initial Pen Color
 * @param {String}  fillColor    Initial Fill Color
 * @param {Number}  penWidth     Initial Pen Width
 * @param {Number}  penStyle     Initial Pen Style
 * @param {Number}  penCapStyle  Initial Pen Cap Style
 * @param {Number}  penJoinStyle Initial Pen Join Style
 * @param {Number}  fillStyle    Initial Fill Style
 * @param {Number}  cornerRadius Initial Corner Radius for Rounded Rectangles
 * @param {Number}  startAngle   Initial Start Angle for Pie Shape
 * @param {Number}  spanAngle    Initial Span Angle for Pie Shape
 */
EllyModel.prototype.addShape = function (shape, x, y, rotation, selected, width, height, aspectRatio, penColor, fillColor, penWidth,
                           penStyle, penCapStyle, penJoinStyle, brushStyle, drawCircle, cornerRadiusX, cornerRadiusY, startAngle, spanAngle) {

    var setShape, setX, setY, setRotation, setSelected, setWidth, setHeight, setAspectRatio, setPenColor, setFillColor, setPenWidth,
        setPenStyle, setPenCapStyle, setPenJoinStyle, setBrushStyle, setDrawCircle, setCornerRadiusX, setCornerRadiusY, setStartAngle, setSpanAngle;
    //debugger;

    if(typeof shape === 'undefined') {
        throw new Error('shape is not an optional parameter');
    } else if(shape.constructor !== String) {
        throw new TypeError('shape must be of the type "String"');
    } else {
        setShape = this.lstShapes[shape];
        if(typeof setShape === 'undefined') {
            throw new Error('Invalid shape "' + shape + '"');
        }
        setShape += 65536;
    }

    if(typeof x === 'undefined') {
        throw new Error('x is not an optional parameter');
    } else if(x.constructor !== Number) {
        throw new TypeError('x must be of the type "Number"');
    } else {
        setX = x;
    }

    if(y.constructor !== Number) {
        throw new TypeError('y must be of the type "Number"');
    } else if(typeof y === 'undefined') {
        throw new Error('y is not an optional parameter');
    } else {
        setY = y;
    }

    if(typeof rotation === 'undefined') {
        throw new Error('rotation is not an optional parameter');
    } else if(rotation.constructor !== Number) {
        throw new TypeError('rotation must be of the type "Number"');
    } else {
        setRotation = rotation;
    }

    if(typeof selected === 'undefined') {
        setSelected = false;
    } else if(selected.constructor !== Boolean) {
        throw new TypeError('selected must be of the type "Boolean"');
    } else {
        setSelected = selected;
    }

    if(typeof width === 'undefined') {
        setWidth = 0;
    } else if(width.constructor !== Number) {
        throw new TypeError('width must be of the type "Number"');
    } else {
        setWidth = width;
    }

    if(typeof height === 'undefined') {
        setHeight = 0;
    } else if(height.constructor !== Number) {
        throw new TypeError('height must be of the type "Number"');
    } else {
        setHeight = height;
    }

    if(typeof aspectRatio === 'undefined') {
        setAspectRatio = false;
    } else if(selected.constructor !== Boolean) {
        throw new TypeError('Aspect ratio must be of the type "Boolean"');
    } else {
        setAspectRatio = aspectRatio;
    }

    if(typeof penColor === 'undefined') {
        setPenColor = '';
    } else if(penColor.constructor !== String) {
        throw new TypeError('penColor must be of the type "String"');
    } else {
        setPenColor = penColor;
    }

    if(typeof fillColor === 'undefined') {
        setFillColor = '';
    } else if(fillColor.constructor !== String) {
        throw new TypeError('fillColor must be of the type "String"');
    } else {
        setFillColor = fillColor;
    }

    if(typeof penWidth === 'undefined') {
        setPenWidth = 0;
    } else if(penWidth.constructor !== Number) {
        throw new TypeError('penWidth must be of the type "Number"');
    } else {
        setPenWidth = penWidth;
    }

    if(typeof penStyle === 'undefined') {
        setPenStyle = this.lstPenStyles.SolidLine;
    } else if(penStyle.constructor !== String) {
        throw new TypeError('penStyle must be of the type "String"');
    } else {
        setPenStyle = this.lstPenStyles[penStyle];
        if(typeof setPenStyle === 'undefined') {
            throw new Error('Invalid pen style "' + penStyle + '"');
        }
    }

    if(typeof penCapStyle === 'undefined') {
        setPenCapStyle = this.lstCapStyles.Round;
    } else if(penCapStyle.constructor !== String) {
        throw new TypeError('penCapStyle must be of the type "String"');
    } else {
        setPenCapStyle = this.lstCapStyles[penCapStyle];
        if(typeof setPenCapStyle === 'undefined') {
            throw new Error('Invalid pen cap style "' + penCapStyle + '"');
        }
    }

    if(typeof penJoinStyle === 'undefined') {
        setPenJoinStyle = this.lstJoinStyles.Round;
    } else if(penJoinStyle.constructor !== String) {
        throw new TypeError('penJoinStyle must be of the type "String"');
    } else {
        setPenJoinStyle = this.lstJoinStyles[penJoinStyle];
        if(typeof setPenJoinStyle === 'undefined') {
            throw new Error('Invalid pen join style "' + penJoinStyle + '"');
        }
    }

    if(typeof brushStyle === 'undefined') {
        setBrushStyle = this.lstBrushStyles.SolidPattern;
    } else if(brushStyle.constructor !== String) {
        throw new TypeError('setBrushStyle must be of the type "String"');
    } else {
        setBrushStyle = this.lstBrushStyles[brushStyle];
        if(typeof setBrushStyle === 'undefined') {
            throw new Error('Invalid brush style "' + brushStyle + '"');
        }
    }
    
    if(typeof drawCircle === 'undefined') {
        setDrawCircle = false;
    } else if(drawCircle.constructor !== Boolean) {
        throw new TypeError('setDrawCircle must be of the type "Boolean"');
    } else {
        setDrawCircle = drawCircle;
    }

    if(typeof cornerRadiusX === 'undefined') {
        setCornerRadiusX = 0;
    } else if(cornerRadiusX.constructor !== Number) {
        throw new TypeError('cornerRadiusX must be of the type "Number"');
    } else {
        setCornerRadiusX = cornerRadiusX;
    }
    
    if(typeof cornerRadiusY === 'undefined') {
        setCornerRadiusY = 0;
    } else if(cornerRadiusY.constructor !== Number) {
        throw new TypeError('cornerRadiusY must be of the type "Number"');
    } else {
        setCornerRadiusY = cornerRadiusY;
    }

    if(typeof startAngle === 'undefined') {
        setStartAngle = 0;
    } else if(startAngle.constructor !== Number) {
        throw new TypeError('startAngle must be of the type "Number"');
    } else {
        setStartAngle = startAngle;
    }

    if(typeof spanAngle === 'undefined') {
        setSpanAngle = 0;
    } else if(spanAngle.constructor !== Number) {
        throw new TypeError('spanAngle must be of the type "Number"');
    } else {
        setSpanAngle = spanAngle;
    }

    // Need to create the necessary structs for the InsertController
    var ShapeInsertOptions = {shapeType: setShape, cornerRadiusX: setCornerRadiusX, cornerRadiusY: setCornerRadiusY, drawCircle: setDrawCircle, startAngle: setStartAngle, spanAngle: setSpanAngle};
    
    var GenericInsertOptions = {positionX: setX, positionY: setY, rotationDegrees: setRotation, initiallySelected: setSelected, itemW: setWidth, itemH: setHeight, aspectRatio: setAspectRatio};
    
    var PenInsertOptions = {penColor: setPenColor, penWidth: setPenWidth, penStyle: setPenStyle, penCapStyle: setPenCapStyle, penJoinStyle: setPenJoinStyle};
    
    var FillInsertOptions = {fillColor: setFillColor, brushStyle: setBrushStyle};
    
    
    
    InsertController.insertShape(ShapeInsertOptions, GenericInsertOptions, PenInsertOptions, FillInsertOptions); 
    
    /*GPCanvasModel.addSimpleShapeItem(setShape, setX, setY, setRotation, setSelected, setWidth, setHeight, setAspectRatio, setPenColor,
                                       setFillColor, setPenWidth, setPenStyle, setPenCapStyle, setPenJoinStyle,
                                       setFillStyle, setCornerRadius, setStartAngle, setSpanAngle);*/
};