/* globals EllyModel, InsertController */


/**
 * adds new label text item to collection/canvas
 * @param {String}  data           Required - the data to set the text item to
 * @param {Number}  x              Required - the x position
 * @param {Number}  y              Required - the y position
 * @param {Number}  rotation       Rotation - default 0
 * @param {Boolean} selected       Selected - default false
 * @param {Number}  width          Width - default 0
 * @param {Number}  height         Height - default 0
 * @param {Boolean} aspectRatio    Enable/disable keeping aspect ratio
 * @param {String}  color          Color
 * @param {Number}  size           Size - default 12
 * @param {String}  font           Initial font style
 * @param {Boolean} bold           Enable/disable bold text
 * @param {Boolean} italic         Enable/disable italic text
 * @param {Boolean} underline      Enable/disable underlined text
 * @param {String}  align          Alignment type
 * @param {Boolean} emptyText      Enable/disable rectangle on empty text                                
 * @param {Boolean} vertical       [[Description]]
 * @param {Boolean} pinnedToCenter Enable/disable pinned to center
 * @param {Boolean} showFrame      Enable/disbale frame
 * @param {String}  penColor       Text color
 * @param {String}  fillColor      Background color
 * @param {Number}  penWidth       Pen width
 * @param {String}  penStyle       Pen style
 * @param {String}  penCapStyle    Pen cap style
 * @param {String}  penJoinStyle   Pen join style
 * @param {String}  fillStyle      Fill style
 */
EllyModel.prototype.addTextItem = function(data, x, y, rotation, selected, width, height, aspectRatio, color, 
                             size, font, bold, italic, underline, align, vertical, pinnedToCenter,
                             penColor, fillColor, penWidth, penStyle, penCapStyle, penJoinStyle, fillStyle, emptyText) {

    var setData, setX, setY, setRotation, setSelected, setWidth, setHeight, setAspectRatio, 
        setColor, setSize, setFont, setBold, setItalic, setUnderline, setAlign, setVertical,
        setPinnedToCenter, setPenColor, setFillColor, setPenWidth, setPenStyle, 
        setPenCapStyle, setPenJoinStyle, setFillStyle, setEmptyText;

    if(typeof data === 'undefined') {
        throw new Error('data is a required argument');
    } else if(data.constructor !== String) {
        throw new TypeError('data must be of type "String"');
    } else {
        setData = data;
    }

    if(typeof x === 'undefined') {
        throw new Error('x is not an optional parameter');
    } else if(x.constructor !== Number) {
        throw new TypeError('x must be of the type "Number"');
    } else {
        setX = x;
    }

    if(typeof y === 'undefined') {
        throw new Error('y is not an optional parameter');
    } else if(y.constructor !== Number) {
        throw new TypeError('y must be of the type "Number"');
    } else {
        setY = y;
    }

    if(typeof rotation === 'undefined') {
        setRotation = 0;
    } else if(rotation.constructor !== Number) {
        throw new TypeError('rotation must be of the type "Number"');
    } else {
        setRotation = rotation;
    }

    if(typeof selected === 'undefined') {
        setSelected = false;
    } else if(selected.constructor !== Boolean) {
        throw new TypeError('selected must be of the type "Number"');
    } else {
        setSelected = selected;
    }

    if(typeof width === 'undefined') {
        setWidth = 0;
    } else if(width.constructor !== Number) {
        throw new TypeError('width must be of the type "Number"');
    } else {
        setWidth = width;
    }

    if(typeof height === 'undefined') {
        setHeight = 0;
    } else if(height.constructor !== Number) {
        throw new TypeError('height must be of the type "Number"');
    } else {
        setHeight = height;
    }

    if(typeof aspectRatio === 'undefined') {
        setAspectRatio = false;
    } else if(selected.constructor !== Boolean) {
        throw new TypeError('Aspect ratio must be of the type "Number"');
    } else {
        setAspectRatio = aspectRatio;
    }

    if(typeof color === 'undefined') {
        setColor = '';
    } else if(color.constructor !== String) {
        throw new TypeError('setColor must be of the type "String"');
    } else {
        setColor = color;
    }

    if(typeof size === 'undefined') {
        setSize = 12;
    } else if(size.constructor !== Number) {
        throw new TypeError('size must be of type "Number"');
    } else {
        setSize = size;
    }

    if(typeof font === 'undefined') {
        setFont = '';
    } else if(font.constructor !== String) {
        throw new TypeError('font must be of type "String"');
    } else {
        setFont = font;
    }

    if(typeof bold === 'undefined') {
        setBold = 0;
    } else if(bold.constructor !== Number) {
        throw new TypeError('bold must be of type "Number"');
    } else {
        if(bold === 1) {
            setBold = 1;
        } else {
            setBold = 0;
        }
    }

    if(typeof italic === 'undefined') {
        setItalic = 0;
    } else if(italic.constructor !== Number) {
        throw new TypeError('italic must be of type "Number"');
    } else {
        if(italic === 1) {
            setItalic = 1;
        } else {
            setItalic = 0;
        }
    }

    if(typeof underline === 'undefined') {
        setUnderline = 0;
    } else if(underline.constructor !== Number) {
        throw new TypeError('underline must be of type "Number"');
    } else {
        if(underline === 1) {
            setUnderline = 1;
        } else {
            setUnderline = 0;
        }
    }

    if(typeof align === 'undefined') {
        setAlign = 1;
    } else if(align.constructor !== String) {
        throw new TypeError('align must be of type "String"');
    } else {
        setAlign = this.lstAlignmentEnum[align];
        if(typeof setAlign === 'undefined') {
            throw new Error('Invalid Alignment "' + align + '"');
        }
    }

    if(typeof vertical === 'undefined') {
        setVertical = 0;
    } else if(vertical.constructor !== Number) {
        throw new TypeError('vertical must be of type "Number"');
    } else {
        if(vertical === 1) {
            setVertical = 1;
        } else {
            setVertical = 0;
        }
    }

    if(typeof pinnedToCenter === 'undefined') {
        setPinnedToCenter = 0;
    } else if(pinnedToCenter.constructor !== Number) {
        throw new TypeError('pinnedToCenter must be of type "Number"');
    } else {
        if(pinnedToCenter === 1) {
            setPinnedToCenter = 1;
        } else {
            setPinnedToCenter = 0;
        }
    }

    if(typeof penColor === 'undefined') {
        setPenColor = '';
    } else if(penColor.constructor !== String) {
        throw new TypeError('penColor must be of the type "String"');
    } else {
        setPenColor = penColor;
    }

    if(typeof fillColor === 'undefined') {
        setFillColor = '';
    } else if(fillColor.constructor !== String) {
        throw new TypeError('fillColor must be of the type "String"');
    } else {
        setFillColor = fillColor;
    }

    if(typeof penWidth === 'undefined') {
        setPenWidth = 0;
    } else if(penWidth.constructor !== Number) {
        throw new TypeError('penWidth must be of the type "Number"');
    } else {
        setPenWidth = penWidth;
    }

    if(typeof penStyle === 'undefined') {
        setPenStyle = this.lstPenStyles.SolidLine;
    } else if(penStyle.constructor !== String) {
        throw new TypeError('penStyle must be of the type "String"');
    } else {
        setPenStyle = this.lstPenStyles[penStyle];
        if(typeof setPenStyle === 'undefined') {
            throw new Error('Invalid pen style "' + penStyle + '"');
        }
    }

    if(typeof penCapStyle === 'undefined') {
        setPenCapStyle = this.lstCapStyles.Round;
    } else if(penCapStyle.constructor !== String) {
        throw new TypeError('penCapStyle must be of the type "String"');
    } else {
        setPenCapStyle = this.lstCapStyles[penCapStyle];
        if(typeof setPenCapStyle === 'undefined') {
            throw new Error('Invalid pen cap style "' + penCapStyle + '"');
        }
    }

    if(typeof penJoinStyle === 'undefined') {
        setPenJoinStyle = this.lstJoinStyles.Round;
    } else if(penJoinStyle.constructor !== String) {
        throw new TypeError('penJoinStyle must be of the type "String"');
    } else {
        setPenJoinStyle = this.lstJoinStyles[penJoinStyle];
        if(typeof setPenJoinStyle === 'undefined') {
            throw new Error('Invalid pen join style "' + penJoinStyle + '"');
        }
    }

    if(typeof fillStyle === 'undefined') {
        setFillStyle = this.lstBrushStyles.SolidPattern;
    } else if(fillStyle.constructor !== String) {
        throw new TypeError('setFillStyle must be of the type "String"');
    } else {
        setFillStyle = this.lstBrushStyles[fillStyle];
        if(typeof setFillStyle === 'undefined') {
            throw new Error('Invalid fill style "' + fillStyle + '"');
        }
    }
    
    if(typeof emptyText === 'undefined') {
        setEmptyText = false;
    } else if(emptyText.constructor !== Boolean) {
        throw new TypeError('Empty Text must be of the type "Boolean"');
    } else {
        setEmptyText = emptyText;
    }

    // Need to create the necessary structs for the InsertController
    var GenericInsertOptions = {positionX: setX, positionY: setY, rotationDegrees: setRotation, initiallySelected: setSelected, itemW: setWidth, itemH: setHeight, aspectRatio: setAspectRatio};
    
    var PenInsertOptions = {penColor: setPenColor, penWidth: setPenWidth, penStyle: setPenStyle, penCapStyle: setPenCapStyle, penJoinStyle: setPenJoinStyle};
    
    var FillInsertOptions = {fillColor: setFillColor, brushStyle: setFillStyle};
    
    var TextInsertOptions = {textContents: setData, textColor: setColor, textPointSize: setSize, textFontFamily: setFont, textBold: setBold, textItalic: setItalic, textUnderline: setUnderline, textAlign: setAlign, showEmptyText: setEmptyText};
    
    var LabelInsertOptions = {textVertical: setVertical, textPinnedToCenter: setPinnedToCenter};
    
    InsertController.insertLabelText(GenericInsertOptions, PenInsertOptions, FillInsertOptions, TextInsertOptions, LabelInsertOptions);
    
    
    /*GPCanvasModel.addLabelTextItem(setData, setX, setY, setRotation, setSelected,
                                     setWidth, setHeight, setAspectRatio, setColor, setSize, setFont,
                                     setBold, setItalic, setUnderline, setAlign, setVertical, setPinnedToCenter,
                                     setPenColor, setFillColor, setPenWidth,
                                     setPenStyle, setPenCapStyle, setPenJoinStyle, setFillStyle);*/
};