/* globals EllyModel, GPCanvasModel, Barcode1DController, Barcode2DController, FontController, TextAlignController */


/**
 * Sets the selected barcode item's symbol type
 * @param   {String} symbol Symbol to set barcode to
 * @returns {Number} Number of barcode changed signals recieved after change
 */
EllyModel.prototype.setSelectedItemBarcode1DSymbol = function(symbol) {
    Barcode1DController.symbol = this.lstBarcode1DSymbols[symbol];
};

/**
 * Get selected barcodes symbol type
 * @returns {String} Selected barcodes symbol type
 */
EllyModel.prototype.getSelectedItemBarcode1DSymbol = function() {
    var match = false;
    var symbol = parseInt(Barcode1DController.symbol);

    for(var key in this.lstBarcode1DSymbols) {
        if(this.lstBarcode1DSymbols[key] === symbol) {
            match = true;
            return key;
        }
    }

    if(!match) {
        return 'Invalid barcode symbol type';
    }
};

/**
 * Sets the selected barcode item's symbol type
 * @param   {String} symbol Symbol to set barcode to
 * @returns {Number} Number of barcode changed signals recieved after change
 */
EllyModel.prototype.setSelectedItemBarcode2DSymbol = function(symbol) {
    Barcode2DController.symbol = this.lstBarcode2DSymbols[symbol];
};

/**
 * Get selected barcodes symbol type
 * @returns {String} Selected barcodes symbol type
 */
EllyModel.prototype.getSelectedItemBarcode2DSymbol = function() {
    var match = false;
    var symbol = parseInt(Barcode2DController.symbol);

    for(var key in this.lstBarcode2DSymbols) {
        if(this.lstBarcode2DSymbols[key] === symbol) {
            match = true;
            return key;
        }
    }

    if(!match) {
        return 'Invalid barcode symbol type';
    }
};

/**
 * Sets option2 aka check digit for barcode 1D code39 symbol
 * @param {Number} bool true or false
 */
EllyModel.prototype.setSelectedItemBarcode1DCheckDigit = function(bool) {
    Barcode1DController.checkDigit = bool;
};

/**
 * Sets option 2 for barcode symbols that support it
 * @param   {Number} option Option 2 set to this value
 * @returns {Number} Number of change signals sent
 */
EllyModel.prototype.setSelectedItemsBarcode2DOption2 = function(option) {
    Barcode2DController.columns = option;
};

/**
 * Get option2 from selected barcode if supported
 * @returns {Number} Option2 value
 */
EllyModel.prototype.getSelectedItemsBarcodeOption2 = function() {
    return parseInt(Barcode2DController.columns);
};

/**
 * Sets selected barcodes height
 * @param   {Number} height Height to set the barcode to
 * @returns {Number} Number of change signals sent
 */
/*EllyModel.prototype.setSelectedItemsBarcodeHeight = function(height) {
    Barcode1DController.barcodeHeight = height;
};*/

/**
 * Get selected barcodes height
 * @returns {Number} Height of barcode
 */
/*EllyModel.prototype.getSelectedItemsBarcodeHeight = function() {
    return this.stringToRetNum(Barcode1DController.barcodeHeight);
};*/

/**
 * Sets selected barcodes text
 * @param   {String} text Barcode text
 * @returns {Number} Number of change signals sent
 */
EllyModel.prototype.setSelectedItemsBarcode1DText = function(text) {
    Barcode1DController.text = text;
};

/**
 * Get selected barcodes text
 * @returns {String} Barcode text
 */
EllyModel.prototype.getSelectedItemsBarcode1DText = function() {
    return Barcode1DController.text;
};

/**
 * Sets selected barcodes text
 * @param   {String} text Barcode text
 * @returns {Number} Number of change signals sent
 */
EllyModel.prototype.setSelectedItemsBarcode2DText = function(text) {
    Barcode2DController.text = text;
};

/**
 * Get selected barcodes text
 * @returns {String} Barcode text
 */
EllyModel.prototype.getSelectedItemsBarcode2DText = function() {
    return Barcode2DController.text;
};

/**
 * Set selected barcodes whitespace
 * @param   {Number} whitespace Barcode whitespace
 * @returns {Number} Number of change signals sent
 */
EllyModel.prototype.setSelectedItemsBarcode1DWhitespace = function(whitespace) {
    Barcode1DController.whitespace = whitespace;
};

/**
 * Get selected barcodes whitespace
 * @returns {Number} Barcode whitespace
 */
EllyModel.prototype.getSelectedItemsBarcode1DWhitespace = function() {
    return this.stringToRetNum(Barcode1DController.whitespace);
};

/**
 * Set selected barcodes whitespace
 * @param   {Number} whitespace Barcode whitespace
 * @returns {Number} Number of change signals sent
 */
EllyModel.prototype.setSelectedItemsBarcode2DWhitespace = function(whitespace) {
    Barcode2DController.whitespace = whitespace;
};

/**
 * Get selected barcodes whitespace
 * @returns {Number} Barcode whitespace
 */
EllyModel.prototype.getSelectedItemsBarcode2DWhitespace = function() {
    return this.stringToRetNum(Barcode2DController.whitespace);
};

/**
 * Set selected barcodes hide text
 * @param   {Boolean} hide Enable/disable hide text
 * @returns {Number}  Number of change signals sent
 */
EllyModel.prototype.setSelectedItemsBarcode1DHideText = function(hide) {
    Barcode1DController.hideText = hide;
};

/**
 * Get selected barcodes hide text
 * @returns {Number} Enabled/disbaled
 */
EllyModel.prototype.getSelectedItemsBarcode1DHideText = function() {
    return this.stringToRetNum(Barcode1DController.hideText);
};

/**
 * Set selected barcodes hide text
 * @param   {Boolean} hide Enable/disable hide text
 * @returns {Number}  Number of change signals sent
 */
EllyModel.prototype.setSelectedItemsBarcode2DHideText = function(hide) {
    Barcode2DController.hideText = hide;
};

/**
 * Get selected barcodes hide text
 * @returns {Number} Enabled/disbaled
 */
EllyModel.prototype.getSelectedItemsBarcode2DHideText = function() {
    return this.stringToRetNum(Barcode2DController.hideText);
};

/**
 * Set selected barcodes secutiry level
 * @param   {Number} level Secutiry level
 * @returns {Number} Number of change signals sent
 */
EllyModel.prototype.setSelectedItemsBarcode1DSecurityLevel = function(level) {
    Barcode1DController.securityLevel = level;
};

/**
 * Get selected barcodes security level
 * @returns {Number} Barcode secutiry level
 */
EllyModel.prototype.getSelectedItemsBarcode1DSecurityLevel = function() {
    return this.stringToRetNum(Barcode1DController.securityLevel);
};

/**
 * Set selected barcodes secutiry level
 * @param   {Number} level Secutiry level
 * @returns {Number} Number of change signals sent
 */
EllyModel.prototype.setSelectedItemsBarcode2DSecurityLevel = function(level) {
    Barcode2DController.securityLevel = level;
};

/**
 * Get selected barcodes security level
 * @returns {Number} Barcode secutiry level
 */
EllyModel.prototype.getSelectedItemsBarcode2DSecurityLevel = function() {
    return this.stringToRetNum(Barcode2DController.securityLevel);
};

/**
 * Set selected barcodes font size
 * @param   {Number} size Font size
 * @returns {Number} Number of change signals sent
 */
EllyModel.prototype.setSelectedItemsBarcodeFontSize = function(size) {
    FontController.fontSize = size;
};

/**
 * Get selected barcodes font size
 * @returns {Number} Font size
 */
EllyModel.prototype.getSelectedItemsBarcodeFontSize = function() {
    return this.stringToRetNum(FontController.fontSize);
};

/**
 * Set selected barcodes font style
 * @param   {String} font Font style
 * @returns {Number} Number of change signals sent
 */
EllyModel.prototype.setSelectedItemsBarcodeFontFamily = function(font) {
    FontController.fontFamily = font;
};

/**
 * Get selected barcodes font style
 * @returns {String} Font style
 */
EllyModel.prototype.getSelectedItemsBarcodeFontFamily = function() {
    return FontController.fontFamily;
};

/**
 * Set selected barcodes text align
 * @param   {Number} align Align value
 * @returns {Number} Number of change signals sent
 */
EllyModel.prototype.setSelectedItemsBarcodeTextAlign = function(align) {
    TextAlignController.alignment = this.lstAlignmentEnum[align];
};

/**
 * Get selected barcodes text align value
 * @returns {String} Text align value
 */
EllyModel.prototype.getSelectedItemsBarcodeTextAlign = function() {
    var match = false;
    var align = parseInt(TextAlignController.alignment);

    for(var key in this.lstAlignmentEnum) {
        if(this.lstAlignmentEnum[key] === align) {
            match = true;
            return key;
        }
    }

    if(!match) {
        return 'Invalid barcode alignment type';
    }
};

/**
 * Enable/disable bold font for selected barcode
 * @param   {Boolean} bold Enable/disable
 * @returns {Number}  Number of change signals sent
 */
EllyModel.prototype.setSelectedItemsBarcodeFontBold = function(bold) {
    FontController.fontBold = bold;
};

/**
 * Get selected barcodes bold text value
 * @returns {Number} Bold enabled/disabled
 */
EllyModel.prototype.getSelectedItemsBarcodeFontBold = function() {
    return this.stringToRetNum(FontController.fontBold);
};

/**
 * Enable/disable italic text for selected barcode
 * @param   {Boolean} italic Enable/disable
 * @returns {Number}  Number of change signals sent
 */
EllyModel.prototype.setSelectedItemsBarcodeFontItalic = function(italic) {
    FontController.fontItalic = italic;
};

/**
 * Get selected barcodes italic text value
 * @returns {Number} Italic enabled/disabled
 */
EllyModel.prototype.getSelectedItemsBarcodeFontItalic = function() {
    return this.stringToRetNum(FontController.fontItalic);
};

/**
 * Enable/disable underlined text for selected barcode
 * @param   {Boolean} underline Enable/disable
 * @returns {Number}  Number of change signals sent
 */
EllyModel.prototype.setSelectedItemsBarcodeFontUnderline = function(underline) {
    FontController.fontUnderline = underline;
};

/**
 * Get selected barcodes underline text value
 * @returns {Number} Enabled/disbaled
 */
EllyModel.prototype.getSelectedItemsBarcodeFontUnderline = function() {
    return this.stringToRetNum(FontController.fontUnderline);
};

/**
 * Enable/disable text above for selected barcode
 * @param   {Boolean} above Enable/disable
 * @returns {Number}  Number of change signals sent
 */
EllyModel.prototype.setSelectedItemsBarcodeTextAbove = function(above) {
    Barcode1DController.textAbove = above;
};

/**
 * Get selected barcodes text above value
 * @returns {Number} Enabled/disabled
 */
EllyModel.prototype.getSelectedItemsBarcode1DTextAbove = function() {
    return this.stringToRetNum(Barcode1DController.textAbove);
};

/**
 * Get selected barcodes encoded text
 * @returns {String} Encoded text
 */
EllyModel.prototype.getSelectedItemsBarcode1DEncodedText = function() {
    return Barcode1DController.encodeText;
};

/**
 * Get selected barcodes input mode
 * @returns {Number} Input mode
 */
EllyModel.prototype.getSelectedItemsBarcodeInputMode = function() {
    return this.stringToRetNum(GPCanvasModel.getSelectedItemsBarcodeInputMode());
};

/**
 * Set selected barcodes aspect ratio mode
 * @param   {Number} mode Aspect ratio mode
 * @returns {Number} Number of change signals sent
 */
EllyModel.prototype.setSelectedItemsBarcodeAspectRatioMode = function(mode) {
    Barcode1DController.aspectRatioMode = mode;
};

/**
 * Get selected barcodes aspect ratio mode
 * @returns {Number} Aspect ratio mode
 */
EllyModel.prototype.getSelectedItemsBarcodeAspectRatioMode = function() {
    return this.stringToRetNum(Barcode1DController.aspectRatioMode);
};

/**
 * Check to see if selected barcodes text is valid
 * @returns {Number} Valid/not valid
 */
EllyModel.prototype.getSelectedItemsBarcodeIsValid = function() {
    return this.stringToRetNum(Barcode1DController.isValidInput);
};

/**
 * Set selected 2D barcodes column number
 * @param {Number} columns # of Columns in PDF417
 */
EllyModel.prototype.setSelectedItemsBarcode2DColumns = function(columns) {
    Barcode2DController.columns = columns;
};

