/* globals EllyModel, SupplyPalette */

EllyModel.prototype.PRECISION          = 0.0001;
EllyModel.prototype.LOCAL_UNITS        = 72;
EllyModel.prototype.MIN_SCENE_LENGTH   = 72;
EllyModel.prototype.MAX_SCENE_LENGTH   = 120.0 * 72;
EllyModel.prototype.MIN_PEN_WIDTH      = 3;
EllyModel.prototype.MAX_PEN_WIDTH      = 72;
EllyModel.prototype.MIN_LENGTH         = 3;
EllyModel.prototype.MIN_LINE_LENGTH    = 0.0001;
EllyModel.prototype.MAX_LENGTH         = 120.0 * 72;
EllyModel.prototype.MIN_POSITION       = -1.5 * EllyModel.MAX_SCENE_LENGTH;
EllyModel.prototype.MAX_POSITION       = 2.5 * EllyModel.MAX_SCENE_LENGTH;
EllyModel.prototype.INC_DEC_STEP       = 0.01 * 72;
EllyModel.prototype.MIN_FONT_SIZE      = 5;
EllyModel.prototype.MAX_FONT_SIZE      = 200;
EllyModel.prototype.MIN_CANVAS_LENGTH  = 0.5 * 72;
EllyModel.prototype.MAX_CANVAS_LENGTH  = 120.0 * 72;
EllyModel.prototype.MIN_CANVAS_HEIGHT  = 0.5 * 72;
EllyModel.prototype.MAX_CANVAS_HEIGHT  = 12 * 72;

EllyModel.prototype.lstShapes = {
    'Line': 31,
    'Rectangle': 42,
    'RoundedRectangle': 43,
    'Ellipse': 44,
    'RightTriangle': 51,
    'EquilateralTriangle': 52,
    'Diamond': 53,
    'Pentagon': 54,
    'Hexagon': 55,
    'Octagon': 56
};

EllyModel.prototype.lstObjects = {
    'barcode1D': 29,
    'barcode2D': 30,
    'text': 21,
    'rich text': 22,
    'svg': 11,
    'pixmap': 12,
    'symbol': 13
};

//EllyModel.prototype.lstColors = function() {
//    return SupplyPalette.getPaletteColorNames();
//};

EllyModel.prototype.lstPenStyles = {
    NoPen: 0, // None
    SolidLine: 1, // Solid
    DashLine: 2, // Dash
    DotLine: 3, // Dot
    DashDotLine: 4, // Dash-dot
    DashDotDotLine: 5 // Dash-dot-dot
};

// MG removed some patterns from testing, having them all is not relevant
EllyModel.prototype.lstBrushStyles = {
    /*
     * These are set in commonTypes.h as EllyTest::BrushStyle
     */
    SolidPattern: 1,
    Dense1Pattern: 2,
    Dense2Pattern: 3,
    Dense3Pattern: 4,
    Dense4Pattern: 5,
    Dense5Pattern: 6,
    Dense6Pattern: 7,
    Dense7Pattern: 8,
    HorPattern: 9,
    VerPattern: 10,
    CrossPattern: 11,
    BDiagPattern: 12,
    FDiagPattern: 13,
    DiagCrossPattern: 14,
    LinearGradientPattern: 15,
    RadialGradientPattern: 16,
    ConicalGradientPattern: 17,
};

EllyModel.prototype.lstJoinStyles = {
    Miter: 0,
    Bevel: 64,
    Round: 128
};

EllyModel.prototype.lstCapStyles = {
    Flat: 0x00,
    //Square: 0x10,
    Round: 0x20,
};

EllyModel.prototype.lstBarcode1DSymbols = {
    BARCODE_CODE128: 20, // Code 128 (automatic subset switching)
    BARCODE_CODE128B: 60, // Code 128 (Subset B)
    BARCODE_CODE39: 8, // Code 3 of 9 (Code 39)
    BARCODE_C25MATRIX: 2, // Standard Code 2 of 5
    BARCODE_CODABAR: 18, // Codabar
    BARCODE_UPCA: 34, // UPC A
    BARCODE_UPCE: 37, // UPC E
    BARCODE_EANX: 13, // EAN
    BARCODE_ISBNX: 69, // ISBN (EAN-13 with verification stage)
};

EllyModel.prototype.lstBarcode2DSymbols = {
    BARCODE_DATAMATRIX: 71, // Data Matrix
    BARCODE_PDF417: 55, // PDF417
    BARCODE_QRCODE: 58 // QR Code
};

//EllyModel.prototype.lstAlignmentEnum = {
//    left: 1,
//    center: 0x0084,
//    center: 0x0004,
//    right: 2
//};

EllyModel.prototype.lstAlignmentEnum = {
    AlignLeft: 0x0001,
//    AlignLeading: AlignLeft,
    AlignRight: 0x0002,
//    AlignTrailing: AlignRight,
    AlignHCenter: 0x0004,
//    AlignJustify: 0x0008,
//    AlignAbsolute: 0x0010,
//    AlignHorizontal_Mask = AlignLeft | AlignRight | AlignHCenter | AlignJustify | AlignAbsolute,
//    AlignTop: 0x0020,
//    AlignBottom: 0x0040,
//    AlignVCenter: 0x0080,
//    AlignBaseline: 0x0100,
};

EllyModel.prototype.lstRightArrowTypes = {
    NoArrow: 0x00,
    RightArrow: 0x01,
    RightFilledArrow: 0x03,
    RightChevron: 0x05,
    RightBar: 0x08
};

EllyModel.prototype.lstLeftArrowTypes = {
    NoArrow: 0x00,
    LeftArrow: 0x10,
    LeftFilledArrow: 0x30,
    LeftChevron: 0x50,
    LeftBar: 0x80
};

EllyModel.prototype.lstUnits = {
    Inches: 0,
    Millimeters: 1,
    Points: 2
};

EllyModel.prototype.lstColorHex = {
    
    // RIBBON COLORS
    r_black:                    "#000000",
    r_white:                    "#ffffff",
    r_yellow:                   "#fedb00",
    r_green:                    "#007749",
    r_orange:                   "#ed8b00",
    r_red:                      "#ad2624",
    r_dark_blue:                "#002d72",
    r_violet:                   "#002d72",
    
    // PAPER COLORS
    
    white:                      "#ffffff",
    clear:                      "transparent",
    fluorescent_yellow:         "#ffcc1e",
    soft_pink:                  "#ff77a8",
    orange:                     "#ff5800",
    fluorescent_orange:         "#ff5416", // 5    
    fluorescent_org_red:        "#ff2a0f",
    fluorescent_pink:           "#fd17f4",
    yellow:                     "#fcd116",
    dark_yellow:                "#fcb514",
    creme_brulee:               "#f9e08c",  // 10
    primrose_yellow:            "#f9d616",
    fluorescent_red:            "#f93a2b",
    deep_pink:                  "#f4547c",
    off_green:                  "#f3ffdb",
    off_white:                  "#f0f6e4",  // 15
    lemon:                      "#efea07",
    hydrangea_purple:           "#eda0d3",
    salmon:                     "#ed9e84",
    pink:                       "#ed72aa",
    tangerine:                  "#e23d28", // 20
    dark_beige:                 "#ddd3af",
    red:                        "#dc0b0b",
    beige:                      "#d7d3c7",
    fluorescent_magenta:        "#d6009e",
    sandstone:                  "#cfac8c", // 25
    true_red:                   "#cd202c",
    blossom:                    "#cc0256",
    gold:                       "#cb8d2c",
    imitation_gold:             "#ca9b4a",
    cardinal_red:               "#c41e3a", // 30
    butterfly_blue:             "#b2d1e5",
    carmel:                     "#b28260",
    cherry:                     "#af1e2d",
    blush:                      "#ad005b",
    baby_blue:                  "#a8cee2", // 35
    spectra_red:                "#a32638",
    powder_blue:                "#a0cfeb",
    terra_cotta:                "#a04f11",
    dark_red:                   "#96172e",
    silver:                     "#919693", // 40
    brushed_gold:               "#907c4b",
    olive_green:                "#8e9300",
    lavender:                   "#8977ba",
    raspberry:                  "#87005b",
    magenta:                    "#7d0063", // 45
    cranberry:                  "#782327",
    berry:                      "#66116d",
    fluorescent_green:          "#60dd49",
    iguana_green:               "#60c659",
    sky_blue:                   "#5fa6bf", // 50
    seafoam_green:              "#5eddc1",
    burgundy:                   "#5e172d",
    purple:                     "#56008c",
    chocolate_brown:            "#512826",
    plum:                       "#4c145e", // 55
    brown:                      "#4a3c31",
    dark_brown:                 "#441e1c",
    green:                      "#248d4f",
    yellow_green:               "#1eb53a",
    blue:                       "#164473", // 60
    midnight_blue:              "#0c1c47",
    sapphire_blue:              "#0c1975",
    fluorescent_blue:           "#00aacc",
    light_blue:                 "#00a3dd",
    kelly_green:                "#009977", // 65
    real_teal:                  "#008789",
    spectra_everglade:          "#008566",
    teal:                       "#00848e",
    arctic_blue:                "#0083be",
    sherwood_green:             "#006b3f", // 70
    ocean_blue:                 "#005b99",
    medium_blue:                "#005a8b",
    forest_green:               "#00563f",
    dark_green:                 "#004438",
    dark_navy_blue:             "#002d47", // 75
    dark_blue:                  "#002649",
    vibrant_blue:               "#002395",
    cool_blue:                  "#0018a8",
    battleship_gray:            "#e4e4ed",
    gray:                       "#c0c0c0", // 80
    medium_gray:                "#afaaa3",
    slate_gray:                 "#adafaa",
    silver_gray:                "#85888b",  // "brushed aluminum"
    dark_gray:                  "#666d70",
    black:                      "#000000", // 85
    
};
