/* globals EllyModel, GPCanvasModel, CanvasSettingsController */

/**
 * Enable and disable snap to grid
 * @param {Boolean} snap Enable/disable snap
 */
EllyModel.prototype.setGridSnap = function(snap) {
    GPCanvasModel.snapToGrid(snap);
};

/**
 * Get current snap to grid setting
 * @returns {Boolean} True if snap is enabled
 */
EllyModel.prototype.getGridSnap = function() {
    return GPCanvasModel.getSnapToGrid();
};

/**
 * Set grid type
 * @param {Number} show 0: Disables grid
 *                      1: Shows grid behind items
 *                      2: Shows grid on top of items
 */
EllyModel.prototype.setGridType = function(show) {
    GPCanvasModel.showGrid(show);
};

/**
 * Get grid type
 * @returns {Number} Gets current grid type
 */
EllyModel.prototype.getGridType = function() {
    return GPCanvasModel.getShowGrid();
};

/**
 * Set Grid size
 * @param {Number} value of horizontal grid
 * @param {Number} value of vertical grid
 */
EllyModel.prototype.setGridSize = function(horizGrid, vertGrid) {
    CanvasSettingsController.setGridSize(horizGrid, vertGrid);  
};

/**
 * Set Grid horizontal size
 * @param {Number} value of horizontal grid
 */
EllyModel.prototype.updateHorizGridSize = function(horizGrid) {
    CanvasSettingsController.updateHorizGridSize(horizGrid);
};

/**
 * Set Grid vertical size
 * @param {Number} value of vertical grid
 */
EllyModel.prototype.updateVertGridSize = function(vertGrid) {
    CanvasSettingsController.updateVertGridSize(vertGrid);  
};


/**
 * Get Grid size
 * @returns {Number} Object with grid size info
 */
EllyModel.prototype.getGridSize = function() {
    return CanvasSettingsController.getGridSize();  
};

/**
 * Get Grid size to QVariantList
 * @param {Array} list of grid size as QVariant
 */
EllyModel.prototype.getGridSizeToQVariant = function() {
    return CanvasSettingsController.getGridSizeToQVariant();  
};

