/* globals EllyModel, InsertController */

/**
 * Adds an item to the scene in which the type is determined by a string
 * @param {String} itemName The name the item, returned as a key from lstShapes or lstObjects
 */
EllyModel.prototype.addItemByName = function (itemName, path) {
    
    var itemEnum;
    var defaultSVG = 'resources/svgs/svg1.svg';
    var defaultSymbol = 'resources/symbols/1.svg';
    var defaultImage = 'resources/images/greenTest.jpg';
    // Need to create the necessary structs for the InsertController
    var GenericInsertOptions = {positionX: 0, positionY: 0, rotationDegrees: 0, initiallySelected: true, itemW: 0, itemH: 0, aspectRatio: false};
    if (itemName.constructor !== String) {
        throw new Error('Item names are Strings');
    } else {
        itemEnum = this.lstShapes[itemName];
        if (typeof itemEnum === 'undefined') {
            itemEnum = this.lstObjects[itemName];
            if (typeof itemEnum === 'undefined') {
                throw new Error('Item type "' + itemName + '" not found');
            }
        }
        if (itemEnum.constructor !== Number) {
            throw new Error('Item types are numerical enums. Item dictionary not defined correctly.');
        } else {
            if (itemName === 'barcode1D') {
                InsertController.insertLinearBarcode();
            }
            if (itemName === 'barcode2D') {
                InsertController.insert2DBarcode();
            }
            if (itemName === 'text') {
                InsertController.insertTextLabel();
            }
            if (itemName ==='rich text'){
                InsertController.insertRichText();
            }
            
            // Symbol, SVG and Pixmap all need to pass an image
            if (itemName === 'symbol') {
                var SymbolInsertOptions = {contents: "", color: "black", bgcolor: "", opacity: false, reverse:false};
                if(typeof path === 'undefined') {
                    InsertController.insertSymbol(SymbolInsertOptions, GenericInsertOptions, defaultSymbol);
                } else {
                    InsertController.insertSymbol(SymbolInsertOptions, GenericInsertOptions, path);
                }
            }
            if (itemName === 'svg') {
                if (typeof path === 'undefined'){
                    InsertController.insertSvg(GenericInsertOptions, defaultSVG);
                } else {
                    InsertController.insertSvg(GenericInsertOptions, path);
                }
            }
            if (itemName === 'pixmap') {
                if (typeof path === 'undefined') {
                    InsertController.insertPixmap(GenericInsertOptions, defaultImage);
                } else {
                    InsertController.insertPixmap(GenericInsertOptions, path);
                }
                
            } 
            else {
                //GPCanvasModel.addGenericItem(itemEnum + 65536);
                InsertController.insertShape(itemName);
            }
        }
    }
};