/* globals EllyModel, GPCanvasModel, print */

/**
 * Gets the Z-Order of the selected item
 * @returns {Number} THe Z-Order
 */
EllyModel.prototype.getSelectedItemZOrder = function() {
    var selectedItemIDs = this.getAllSelectedItemIDs();
    if(selectedItemIDs.length > 1) {
        print('[WARNING] Attempted to get the z-order of a multiple selection');
        return undefined;
    } else if(selectedItemIDs.length === 0)  {
        print('[WARNING] Attempted to get the z-order of an empty selection');
        return undefined;
    } else {
        return this.getItemZOrder(selectedItemIDs[0]);
    }
};

/**
 * Returns the Z-Order of an item ID
 * @param   {Number} id The ID of the item
 * @returns {Number} The Item's Z-Order
 */
EllyModel.prototype.getItemZOrder = function(id) {
    if(typeof id === 'undefined') {
        throw new Error('id must be defined');
    } else if(id.constructor !== Number) {
        throw new Error('id must be a Number');
    }

    var itemZValue = GPCanvasModel.getCanvasZMap()[id];

    if(typeof itemZValue === 'undefined') {
        throw new Error('No item found for ID: ' + id);
    } else {
        return Number(itemZValue);   
    }
};

/**
 * Gets a map of all items z values
 * @returns {Object} Map of item z values
 */
EllyModel.prototype.getCanvasZMap = function() {
    var IDZMap = GPCanvasModel.getCanvasZMap();

    // The dict we get from C++ is string, qvariant - we want int, int
    var convertedMap = [];

    for(var itemID in IDZMap) {
        // JavaScript does not allow keys to be integers, they get converted to strings
        var key = itemID;
        var value = parseFloat(IDZMap[itemID]);
        convertedMap[key] = value;
    }

    return convertedMap;
};