/* globals EllyModel, GPCanvasModel, getDictKeyFromValue, LineController, RotationController*/


// SIGNALS //

var signalLineDataChanged = 0;

GPCanvasModel.selectedItemsLineDataChanged.connect(this, function () { signalLineDataChanged += 1; });

/**
 * Resets signal count and returns what the count was at
 * @returns {Number} Signal count
 */
var lineChangedSignal = function() {
    var tempCount = signalLineDataChanged;
    signalLineDataChanged = 0;
    return tempCount;
};

// SETTERS //

/**
 * Sets the p1 x-Coordinate of the selected line item(s)
 * @param {Number} p1x The p1 x-coordinate to set
 */
EllyModel.prototype.setSelectedItemLineP1x = function (p1x) {
    signalLineDataChanged = 0;
    LineController.setPoint1x(p1x);
    return lineChangedSignal();
};
/**
 * Changes the p1 x-Coordinate of the selected line item(s)
 * @param {Number} p1xDelta Change in p1x
 */
EllyModel.prototype.changeSelectedItemLineP1x = function (p1xDelta) {
    signalLineDataChanged = 0;
    LineController.changePoint1x(p1xDelta);
    return lineChangedSignal();
};

/**
 * Sets the p1 y-Coordinate of the selected line item(s)
 * @param {Number} p1y The p1 y-coordinate to set
 */
EllyModel.prototype.setSelectedItemLineP1y = function (p1y) {
    signalLineDataChanged = 0;
    LineController.setPoint1y(p1y);
    return lineChangedSignal();
};
/**
 * Changes the p1 y-Coordinate of the selected line item(s)
 * @param {Number} p1yDelta Change in p1y
 */
EllyModel.prototype.changeSelectedItemLineP1y = function (p1yDelta) {
    signalLineDataChanged = 0;
    LineController.changePoint1y(p1yDelta);
    return lineChangedSignal();
};

/**
 * Sets the p2 x-Coordinate of the selected line item(s)
 * @param {Number} p2x The p2 x-coordinate to set
 */
EllyModel.prototype.setSelectedItemLineP2x = function (p2x) {
    signalLineDataChanged = 0;
    LineController.setPoint2x(p2x);
    return lineChangedSignal();
};
/**
 * Changes the p2 x-Coordinate of the selected line item(s)
 * @param {Number} p1xDelta Change in p1x
 */
EllyModel.prototype.changeSelectedItemLineP2x = function (p2xDelta) {
    signalLineDataChanged = 0;
    LineController.changePoint2x(p2xDelta);
    return lineChangedSignal();
};

/**
 * Sets the p2 y-Coordinate of the selected line item(s)
 * @param {Number} p2y The p2 y-coordinate to set
 */
EllyModel.prototype.setSelectedItemLineP2y = function (p2y) {
    signalLineDataChanged = 0;
    LineController.setPoint2y(p2y);
    return lineChangedSignal();
};
/**
 * Changes the p2 y-Coordinate of the selected line item(s)
 * @param {Number} p1yDelta Change in p1y
 */
EllyModel.prototype.changeSelectedItemLineP2y = function (p2yDelta) {
    signalLineDataChanged = 0;
    LineController.changePoint2y(p2yDelta);
    return lineChangedSignal();
};

/**
 * Sets the line length of the selected line item(s)
 * @param {Number} lineLength The line length to set
 */
EllyModel.prototype.setSelectedItemLineLength = function (lineLength) {
    signalLineDataChanged = 0;
    LineController.setLength(lineLength);
    return lineChangedSignal();
};
/**
 * Changes the line length of the selected line item(s)
 * @param {Number} lineLengthDelta The amount to change the line length by
 */
EllyModel.prototype.changeSelectedItemLineLength = function (lineLengthDelta) {
    signalLineDataChanged = 0;
    LineController.changeLength(lineLengthDelta);
    return lineChangedSignal();
};

/**
 * Sets the line angle of the selected line item(s)
 * @param {Number} lineAngle The line angle to set
 */
EllyModel.prototype.setSelectedItemLineAngle = function (lineAngle) {
    signalLineDataChanged = 0;
    RotationController.setRotation(lineAngle);
    return lineChangedSignal();
};
/**
 * Changes the line angle of the selected line item(s)
 * @param {Number} lineAngleDelta The amount to change the line angle by
 */
EllyModel.prototype.changeSelectedItemLineAngle = function (lineAngleDelta) {
    signalLineDataChanged = 0;
    RotationController.changeRotation(lineAngleDelta);
    return lineChangedSignal();
};

/**
 * Sets the line's left arrow style
 * @param {String} leftArrowStyle The left arrow style to set
 */
EllyModel.prototype.setSelectedItemLineLeftArrow = function(leftArrowStyle) {
    signalLineDataChanged = 0;
    var leftArrowStyleEnum = this.lstLeftArrowTypes[leftArrowStyle];
    if(typeof leftArrowStyleEnum === 'undefined') {
        throw new Error('Arrow Style "' + leftArrowStyle + '" not found');
    }
    LineController.setLeftArrow(leftArrowStyleEnum);
    return lineChangedSignal();
};

/**
 * Sets the line's right arrow style
 * @param {String} rightArrowStyle The right arrow style to set
 */
EllyModel.prototype.setSelectedItemLineRightArrow = function(rightArrowStyle) {
    signalLineDataChanged = 0;
    var rightArrowStyleEnum = this.lstRightArrowTypes[rightArrowStyle];
    if(typeof rightArrowStyleEnum === 'undefined') {
        throw new Error('Arrow Style "' + rightArrowStyle + '" not found');
    }
    LineController.setRightArrow(rightArrowStyleEnum);
    return lineChangedSignal();
};

// GETTERS //

/**
 * Returns the p1 x-Coordinate of the selected item(s)
 * @returns {Number} The p1 x-Coordinate
 */
EllyModel.prototype.getSelectedItemLineP1x = function () {
    return this.stringToRetNum(LineController.point1x);
};

/**
 * Returns the p1 y-Coordinate of the selected item(s)
 * @returns {Number} The p1 y-Coordinate
 */
EllyModel.prototype.getSelectedItemLineP1y = function () {
    return this.stringToRetNum(LineController.point1y);
};

/**
 * Returns the p2 x-Coordinate of the selected item(s)
 * @returns {Number} The p2 x-Coordinate
 */
EllyModel.prototype.getSelectedItemLineP2x = function () {
    return this.stringToRetNum(LineController.point2x);
};

/**
 * Returns the p2 y-Coordinate of the selected item(s)
 * @returns {Number} The p2 y-Coordinate
 */
EllyModel.prototype.getSelectedItemLineP2y = function () {
    return this.stringToRetNum(LineController.point2y);
};

/**
 * Returns the line length of the selected item(s)
 * @returns {Number} The line length
 */
EllyModel.prototype.getSelectedItemLineLength = function () {
    return this.stringToRetNum(LineController.length);
};

/**
 * Returns the line angle of the selected item(s)
 * @returns {Number} The line angle
 */
EllyModel.prototype.getSelectedItemLineAngle = function () {
    return this.stringToRetNum(RotationController.rotation);
};

/**
 * Gets the line's left arrow style
 * @returns {String} The line's left arrow style
 */
EllyModel.prototype.getSelectedItemLineLeftArrow = function() {
    var leftArrowStyleEnum = Number(LineController.leftArrow);
    return getDictKeyFromValue(this.lstLeftArrowTypes, leftArrowStyleEnum);
};

/**
 * Gets the line's right arrow style
 * @returns {String} The line's right arrow style
 */
EllyModel.prototype.getSelectedItemLineRightArrow = function() {
    var rightArrowStyleEnum = Number(LineController.rightArrow);
    return getDictKeyFromValue(this.lstRightArrowTypes, rightArrowStyleEnum);
};