/* global EllyModel, GPCanvasModel, getDictKeyFromValue, EditController */

EllyModel.prototype.getAllItemTypes = function() {
    var shapeEnumsList = GPCanvasModel.getAllCanvasItemsShapes();
    var returnList = [];
    for(var i = 0; i < shapeEnumsList.length; i++) {
        var shapeEnum = shapeEnumsList[i] - 65536;
        var shapeName = getDictKeyFromValue(this.lstShapes, shapeEnum);
        if(typeof shapeName === 'undefined') {
            shapeName = getDictKeyFromValue(this.lstObjects, shapeEnum);
        }
        returnList.push(shapeName);
    }
    return returnList;
};

/**
 * Returns the type of an item
 * @param   {Number} id The item's ID
 * @returns {String} The item's type
 */
EllyModel.prototype.getItemType = function(id) {
    var items = this.getAllItemTypes();
    var IDs = this.getAllItemIDs();

    if(items.length !== IDs.length) {
        throw new Error('IDs length (' + items.length + ') !== items length (' + IDs.length + ')');
    }

    for(var i = 0; i < IDs.length; i++) {
        if(IDs[i] === id) {
            return items[i];
        }
    }
};

/**
 * Returns the type of the most recently added item
 * @returns {String} The most recently added item's type
 */
EllyModel.prototype.getLastItemType = function() {
    return this.getItemType(this.getLastItemID());
};

/**
 * Deletes all selected items in the scene
 */
EllyModel.prototype.deleteSelected = function () {
    EditController.deleteItems();
};

/**
 * Locks selected items
 */
EllyModel.prototype.lockSelectedItems = function () {
    EditController.lockItems(true);
};

/**
 * Unlocks selected items
 */
EllyModel.prototype.unlockSelectedItems = function () {
    EditController.lockItems(false);
};

/**
 * Returns the locked status of selected items
 * @returns {Boolean} Returns true if at least one selected item is locked
 */
EllyModel.prototype.getSelectedItemLocked = function () {
    return GPCanvasModel.getLockOnSelectedItems;
};

/**
 * Returns true if all of the selected items are locked
 * @returns {Boolean} True if all selected items are locked
 */
EllyModel.prototype.getAllSelectedItemsLocked = function() {
    return GPCanvasModel.getLockOnAllSelectedItems;
};

/**
 * Cuts the selected items
 */
EllyModel.prototype.cutSelectedItems = function() {
    EditController.cutItems();
};

/**
 * Copies the selected items
 */
EllyModel.prototype.copySelectedItems = function() {
    EditController.copyItems();
};

/**
 * Pastes the selected items
 */
EllyModel.prototype.pasteClipboardItems = function() {
    EditController.pasteItems();
};

/**
 * Sends all selected items to the front
 */
EllyModel.prototype.bringToFront = function() {
    GPCanvasModel.toFront();
};

/**
 * Brings all selected items forward
 */
EllyModel.prototype.bringForward = function() {
    GPCanvasModel.forward();
};

/**
 * Sends all selected items to the back
 */
EllyModel.prototype.sendToBack = function() {
    GPCanvasModel.toBack();
};

/**
 * Sends all selected items backward
 */
EllyModel.prototype.sendBack = function() {
    GPCanvasModel.backward();
};

/**
 * Searches through an array using the value to return the matching key
 */
EllyModel.prototype.arraySearch = function(array,value) {
    for (var key in array) {
        if (array[key] === value) {                   
            return key;
        }
    }
    return false;
    
};

/**
 * Searches an array to see if the passed value is contained value found and returns the key
 */
EllyModel.prototype.arrayContainsSearch = function(array, value) {
    for (var key in array) {
        if (value.toLowerCase().indexOf(array[key].toLowerCase()) != -1){
            return key; 
        }
    }  
    return false;
};
