/* globals EllyModel, GPCanvasModel */

/**
 * Sets selected item(s) as non-printable
 */
EllyModel.prototype.setSelectedItemsNonPrintable = function() {
    EditController.setItemsNonprintable();
};

/**
 * Toggles ALL items being non-printable
 * @param {Boolean} nonprintable True to set all items as non-printable
 */
EllyModel.prototype.setAllItemsNonPrintable = function(nonprintable) {
    EditController.setItemsNonprintable(nonprintable);
};

/**
 * Get non-printable property of specified item
 * @param   {Number}  itemID ID of item to check
 * @returns {Boolean} True if item is non-printable
 */
EllyModel.prototype.getItemNonprintable = function(itemID) {
    return GPCanvasModel.getItemIsNonprintable(itemID);
};

/**
 * Allows print of non-printable items
 * @param {Boolean} printNonprintable True to allow printing of non-printable items
 */
EllyModel.prototype.printNonPrintableItems = function(printNonprintable) {
    GPCanvasModel.printNonPrintableItems(printNonprintable);
};

/**
 * Allows non-printable items to be visable on the scene
 * @param {Boolean} showNonprintable True to make non-printable items visible
 */
EllyModel.prototype.showNonPrintableItems = function(showNonprintable) {
    GPCanvasModel.setSceneShowsNonPrintableItems(showNonprintable);
};