/* globals EllyModel, RotationController, PositionController, SizeController */


EllyModel.prototype.setSelectedItemRotation = function (degrees) {
    this.selectedItemsRotationChangedSignalCount = 0;
    RotationController.rotation = degrees;
    return this.rotationChangedSignal();
};

EllyModel.prototype.changeSelectedItemRotation = function (degrees) {
    this.selectedItemsRotationChangedSignalCount = 0;
    RotationController.changeRotation(degrees);
    return this.rotationChangedSignal();
};

EllyModel.prototype.getSelectedItemRotation = function () {
    return this.stringToRetNum(RotationController.rotation);
};

/**
 * Sets the X-Coordinate of the selected item(s)
 * @param {Number} posX The X-Coordinate to set
 */
EllyModel.prototype.setSelectedItemX = function (posX) {
    this.selectedItemsPositionChangedSignalCount = 0;
    PositionController.posX = posX;
    return this.XChangedSignal();
};

/**
 * Returns the X-Coordinate of the selected item(s)
 * @returns {Number} The X-Coordinate
 */
EllyModel.prototype.getSelectedItemX = function () {
    return this.stringToRetNum(Number(PositionController.posX));
};

/**
 * Sets the Y-Coordinate of the selected item(s)
 * @param {Number} posY The Y-Coordinate to set
 */
EllyModel.prototype.setSelectedItemY = function (posY) {
    this.selectedItemsPositionChangedSignalCount = 0;
    PositionController.posY = posY;
    return this.YChangedSignal();
};

/**
 * Returns the Y-Coordinate of the selected item(s)
 * @returns {Number} The Y-Coordinate
 */
EllyModel.prototype.getSelectedItemY = function () {
    return this.stringToRetNum(Number(PositionController.posY));
};

/**
 * Sets the width of the selected items
 * @param {Number}  width     The width to set
 * @param {Boolean} keepRatio Whether or not to keep the aspect ratio
 */
EllyModel.prototype.setSelectedItemWidth = function (width, keepRatio) {
    this.selectedItemsSizeChangedSignalCount = 0;
    var aspect = false;
    if (typeof keepRatio !== 'undefined') {
        if (keepRatio.constructor !== Boolean) {
            throw new Error('keepRatio must be a Boolean');
        } else {
            aspect = keepRatio;
        }
    }

    SizeController.setWidth(width, aspect);
    return this.sizeChangedSignal();
};

/**
 * Changes the width of the selected items
 * @param {Number}  width     The width to change by
 * @param {Boolean} keepRatio Whether or not to keep the aspect ratio
 */
EllyModel.prototype.changeSelectedItemWidth = function (widthDelta, keepRatio) {
    this.selectedItemsSizeChangedSignalCount = 0;
    var aspect = false;
    if (typeof keepRatio !== 'undefined') {
        if (keepRatio.constructor !== Boolean) {
            throw new Error('keepRatio must be a Boolean');
        } else {
            aspect = keepRatio;
        }
    }

    SizeController.changeWidth(widthDelta, aspect);
    return this.sizeChangedSignal();
};

/**
 * Returns the selected items' width
 * @returns {Number} The width of the selected item(s)
 */
EllyModel.prototype.getSelectedItemWidth = function () {
    return this.stringToRetNum(SizeController.width());
};

/**
 * Sets the height of the selected items
 * @param {Number}  height    The height to set
 * @param {Boolean} keepRatio Whether or not to keep the aspect ratio
 */
EllyModel.prototype.setSelectedItemHeight = function (height, keepRatio) {
    this.selectedItemsSizeChangedSignalCount = 0;
    var aspect = false;
    if (typeof keepRatio !== 'undefined') {
        if (keepRatio.constructor !== Boolean) {
            throw new Error('keepRatio must be a Boolean');
        } else {
            aspect = keepRatio;
        }
    }

    SizeController.setHeight(height, aspect);
    return this.sizeChangedSignal();
};

/**
 * Changes the height of the selected items
 * @param {Number}  height    The height to change by
 * @param {Boolean} keepRatio Whether or not to keep the aspect ratio
 */
EllyModel.prototype.changeSelectedItemHeight = function (heightDelta, keepRatio) {
    this.selectedItemsSizeChangedSignalCount = 0;
    var aspect = false;
    if (typeof keepRatio !== 'undefined') {
        if (keepRatio.constructor !== Boolean) {
            throw new Error('keepRatio must be a Boolean');
        } else {
            aspect = keepRatio;
        }
    }

    SizeController.changeHeight(heightDelta, aspect);
    return this.sizeChangedSignal();
};

/**
 * Returns the selected items' height
 * @returns {Number} The height of the selected item(s)
 */
EllyModel.prototype.getSelectedItemHeight = function () {
    return this.stringToRetNum(SizeController.height());
};