/* globals EllyModel, GPCanvasModel, CanvasSettingsController, ScriptHelper */

/**
 * Deletes all items in the scene
*/
EllyModel.prototype.clearScene = function() {
    GPCanvasModel.clearScene();
};

/**
 * Returns an object containing the canvas width and height
 * @returns {Object} An object with the properties of width, height
 */
EllyModel.prototype.getCanvasSize = function () {
    var size = CanvasSettingsController.getCanvasSizeToQVariant();
    return {
        width: size[0],
        height: size[1]
    };
};
/**
 * Sets the Canvas Background Color
 * @param {QColor} color The color to set
 */
EllyModel.prototype.setCanvasBackgroundColor = function(color) {
    ScriptHelper.setCanvasColor(GPCanvasModel, color);
};

/**
 * Sets the size of the current canvas
 * @param {Number} width  The width to set
 * @param {Number} height The height to set
 */
EllyModel.prototype.setCanvasSize = function (width, height, scaleItems) {
    CanvasSettingsController.checkAndSetCanvasSize(width, height, scaleItems);
};

/**
 * Sets canvas margin values
 * @param {number} left   left margin
 * @param {number} top    top margin
 * @param {number} right  right margin
 * @param {number} bottom bottom margin
 */
EllyModel.prototype.setCanvasMargins = function (left, top, right, bottom) {
    CanvasSettingsController.setCanvasMargins(left, top, right, bottom);
};

/**
 * Gets canvas margin values
 * @returns {Array} Margin values for current canvas
 */
EllyModel.prototype.getCanvasMargins = function () {
    return CanvasSettingsController.getCanvasMarginsToQVariant();
};

/**
 * Gets scene rect information
 * @returns {Object} Contains left, top, width, height, right, and bottom of scene rect
 */
EllyModel.prototype.getSceneRect = function() {
    var canvasRect = CanvasSettingsController.getSceneRectToQVariant();
    return {
        left:   canvasRect[0],
        top:    canvasRect[1],
        width:  canvasRect[2],
        height: canvasRect[3],
        right:  canvasRect[4],
        bottom: canvasRect[5]
    };
};

/**
 * Get information about the scene
 * @returns {Array} Left, top, width, and height
 */
EllyModel.prototype.getSceneSize = function() {
    return CanvasSettingsController.getSceneRectToQVariant();
};