/* globals EllyModel, GPCanvasModel */

var selectedItemsChangedSignalCount = 0;
var selectedItemsListIsEmptySignalCount = 0;

GPCanvasModel.selectedItemsChanged.connect(this, function (notEmpty) {
    if(notEmpty) {
        selectedItemsChangedSignalCount += 1;
    } else {
        selectedItemsListIsEmptySignalCount += 1;
    }
});

var itemChangedSignal = function() {
    var tempCount = selectedItemsChangedSignalCount;
    selectedItemsChangedSignalCount = 0;
    return tempCount;
};

var selectedItemsListIsEmptySignal = function() {
    var tempCount = selectedItemsListIsEmptySignalCount;
    selectedItemsListIsEmptySignalCount = 0;
    return tempCount;
};

/**
 * Sets an item to selected
 * @param {Number} id The item's ID
 */
EllyModel.prototype.selectItem = function (id) {
    selectedItemsChangedSignalCount = 0;
    this.validateID(id);
    GPCanvasModel.selectItemById(id, true);
    return itemChangedSignal();
};

/**
 * Deselects an item
 * @param {Number} id The item's ID
 */
EllyModel.prototype.deselectItem = function (id) {
    selectedItemsListIsEmptySignalCount = 0;
    this.validateID(id);
    GPCanvasModel.selectItemById(id, false);
    return selectedItemsListIsEmptySignal();
};

/**
 * Gets the type of a single selected item
 * @returns {String} The item's type
 */
EllyModel.prototype.getSelectedItemType = function() {
    var itemIDs = this.getAllSelectedItemIDs();
    if(itemIDs.length !== 1) {
        return undefined;
    }
    return this.getItemType(itemIDs[0]);
};

/**
 * Returns the selected status of an item ID
 * @param   {Number}  id The item's ID
 * @returns {Boolean} True if selected, false if not
 */
EllyModel.prototype.isSelected = function (id) {
    var IDs = this.getAllSelectedItemIDs();
    if (IDs.indexOf(id) !== -1) {
        return true;
    } else {
        return false;
    }
};

/**
 * Selects all items in the scene
 */
EllyModel.prototype.selectAll = function () {
    selectedItemsChangedSignalCount = 0;
    GPCanvasModel.selectAllCanvasItems();
    return itemChangedSignal();
};

/**
 * Deselects all items in the scene
 */
EllyModel.prototype.deselectAll = function () {
    selectedItemsListIsEmptySignalCount = 0;
    GPCanvasModel.clearSelection();
    return selectedItemsListIsEmptySignal();

};

EllyModel.prototype.selectLastItem = function() {
    this.deselectAll();
    this.selectItem(this.getLastItemID());
};
