/* global EllyModel, GPCanvasModel, getDictKeyFromValue, PenController, PenColorController, FillColorController, BrushController, RoundRectController */

EllyModel.prototype.setSelectedItemPenWidth = function (width) {
    this.selectedItemsPenWidthChangedSignalCount = 0;

    if (width.constructor !== Number) {
        throw new Error('Pen width must be a number');
    }
    //PenController.setPenWidth = width;
    PenController.penWidth = width;

    return this.penWidthChangedSignal();
};

EllyModel.prototype.changeSelectedItemsPenWidth = function (incrementWidth) {

    this.selectedItemsPenWidthChangedSignalCount = 0;

    if (incrementWidth.constructor !== Number) {
        throw new Error('Pen width must be a number');
    }
    PenController.changePenWidth = incrementWidth;

    return this.penWidthChangedSignal();
};

EllyModel.prototype.getSelectedItemPenWidth = function () {
    return this.stringToRetNum(PenController.penWidth);
};


EllyModel.prototype.setSelectedItemPenColor = function (penColor/*, noWarn*/) {
    this.signalPenColorChanged = 0;
    PenColorController.penColor = penColor;
    return this.penColorChangedSignal();
};

EllyModel.prototype.getSelectedItemPenColor = function () {
    var currentHex = PenColorController.penColor;
    if (currentHex === '') {
        return '<none>';
    } else {
        return currentHex;
    }
};

EllyModel.prototype.setSelectedItemPenStyle = function (penStyle) {
    var penStyleEnum = this.lstPenStyles[penStyle];
    if (typeof penStyleEnum === 'undefined') {
        throw new Error('Pen style "' + penStyle + '" not found');
    }
    PenController.penStyle = penStyleEnum;
};

EllyModel.prototype.getSelectedItemPenStyle = function () {
    var penStyleEnum = Number(PenController.penStyle);
    return getDictKeyFromValue(this.lstPenStyles, penStyleEnum);
};

EllyModel.prototype.setSelectedItemPenCapStyle = function (penCapStyle) {
    var penCapStyleEnum = this.lstCapStyles[penCapStyle];
    if (typeof penCapStyleEnum === 'undefined') {
        throw new Error('Pen cap style "' + penCapStyle + '" not found');
    }
    PenController.penCapStyle = penCapStyleEnum;
};

EllyModel.prototype.getSelectedItemPenCapStyle = function () {
    var capStyleEnum = Number(PenController.penCapStyle);
    return getDictKeyFromValue(this.lstCapStyles, capStyleEnum);
};

EllyModel.prototype.setSelectedItemPenJoinStyle = function (penJoinStyle) {
    var penJoinStyleEnum = this.lstJoinStyles[penJoinStyle];
    if (typeof penJoinStyleEnum === 'undefined') {
        throw new Error('Pen Join style "' + penJoinStyle + '" not found');
    }
    PenController.penJoinStyle = penJoinStyleEnum;
};

EllyModel.prototype.getSelectedItemPenJoinStyle = function () {
    var joinStyleEnum = Number(PenController.penJoinStyle);
    return getDictKeyFromValue(this.lstJoinStyles, joinStyleEnum);
};

/**
 * Sets the fill color of the selected item(s)
 * @param {String} color The name of the fill color to set
 */
EllyModel.prototype.setSelectedItemFillColor = function (color/*, noWarn*/) {
    this.selectedItemsFillColorChangedSignalCount = 0;
    FillColorController.fillColor = color;

    return this.fillColorChangedSignal();
};

/**
 * Returns the fill color of the selected item(s)
 * @returns {String} The fill color
 */
EllyModel.prototype.getSelectedItemFillColor = function () {
    var currentHex = FillColorController.fillColor;
    if (currentHex === '') {
        return 'none';
    } else {
        return currentHex;
    }
};

EllyModel.prototype.setSelectedItemBrushStyle = function (brushStyle) {
    var brushStyleEnum = this.lstBrushStyles[brushStyle];
    if (typeof brushStyleEnum === 'undefined') {
        throw new Error('Brush style "' + brushStyle + '" not found');
    }
    BrushController.setBrushStyle(brushStyleEnum);
};

EllyModel.prototype.getSelectedItemBrushStyle = function () {
    var brushStyleEnum = Number(BrushController.brushStyle);
    return getDictKeyFromValue(this.lstBrushStyles, brushStyleEnum);
};

EllyModel.prototype.setSelectedItemRectXRadius = function(radius) {
    RoundRectController.setXRadius(radius);
};

EllyModel.prototype.getSelectedItemRectXRadius = function() {
    return this.stringToRetNum(RoundRectController.xRadius);
};

EllyModel.prototype.setSelectedItemRectYRadius = function(yRadius) {
    RoundRectController.setYRadius(yRadius);
};

EllyModel.prototype.getSelectedItemRectYRadius = function() {
    return this.stringToRetNum(RoundRectController.yRadius);
};
