/* globals EllyModel, SupplyPropertiesTest */


/**
 * Changes the color of the loaded supply
 * @param {string} color - Color of new supply 
 */
EllyModel.prototype.setBackgroundSupply = function(color){
    SupplyPropertiesTest.changeLoadedBackground(color);
};

/**
 * Changes the colors of the loaded ribbons
 * @param {Array} colors list of the colors of new ribbons
 */
EllyModel.prototype.setRibbonSupply = function(colors){
    SupplyPropertiesTest.changeLoadedRibbon(colors);
};

/**
 * Returns list of all loaded ribbon colors
 * @returns {Array} list of loaded ribbons
 */
EllyModel.prototype.getRibbonSupplies = function(){
    return SupplyPropertiesTest.getLoadedRibbonColors();
};

/**
 * Returns all possible colors
 * @returns {Array} list of all possible colors
 */
EllyModel.prototype.lstColors = function(){
    return SupplyPropertiesTest.getAllColorsToVariant();
};

/**
 * Returns all possible supply types
 * @returns {Array} list of all possible supply types
 */
EllyModel.prototype.getAllSupplyColors = function(){
    return SupplyPropertiesTest.getAllSupplyNames();
};

/**
 * Returns currently loaded supply type
 * @returns {string} loaded supply
 */
EllyModel.prototype.getLoadedSupply = function(){
    return SupplyPropertiesTest.getLoadedSupplyName();
};

/**
 * Returns currently loaded color types
 * @returns {Array} QColor - loaded palette
 */
EllyModel.prototype.getPaletteLoaded = function(){
    return SupplyPropertiesTest.getPrintingPalette();
};