/* globals EllyModel, TestSuite, TestCase, getSystemFontFamilies, require */

// Include necessary files
require('../../model.js');
require('../../framework.js');

/****************************************/
/*              Variables               */
/****************************************/

Elly = new EllyModel();
var date = new Date();

// Defaults
var canvasSize = Elly.getCanvasSize();
var textWidth = canvasSize.width;
var textHeight = canvasSize.height;

// Colors
var color1 = Elly.lstColorHex.black;
var color2 = Elly.lstColorHex.white;

// Printer Data
var dataQA = [];
var ribbon1     = "K861123";
var ribbon1Heat = "9";
var ribbon2     = "K861110";
var ribbon2Heat = "10";
var printSpeed  = "2";
var serialNum   = "1234567890";

// Date String
var dateMDY     = (date.getMonth()+1) + "-" + date.getDate() + "-" + date.getFullYear();

// Text Strings
var descText    = "Testing the DuraLabel Kodiak Max\n\nThis label was printed at the speed and\ndarkness listed below. Other speed\ndarkness combinations will also provide\nacceptable results. In general, the\ndarkness should be increased as print\nspeed is increased and lowered as\nprint speed is lowered.";

var testText    = "SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT\nSMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT\nSMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT\nSMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT\nSMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT\nSMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT\nSMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT\nSMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT\nSMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT\nSMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT\n\nSMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT\nSMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT\nSMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT\nSMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT\nSMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT\nSMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT\nSMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT\nSMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT\nSMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT\nSMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT SMALL TEXT\n";

// Symbol Data
var runSymbol   = "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<!-- Generator: Adobe Illustrator 14.0.0, SVG Export Plug-In . SVG Version: 6.00 Build 43363)  -->\n<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\" \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n<svg version=\"1.1\" id=\"Layer_1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" x=\"0px\" y=\"0px\"\n	 width=\"324px\" height=\"324px\" viewBox=\"0 0 324 324\" enable-background=\"new 0 0 324 324\" xml:space=\"preserve\">\n<rect id=\"background_fix\" fill=\"#ffffff\" stroke=\"none\" fill-opacity=\"0\" x=\"0\" y=\"0\" width=\"324\" height=\"324\" />\n<g>\n	<path d=\"M315.25,0C8.75,0,8.75,0,8.75,0C4,0,0,4,0,8.75c0,306.5,0,306.5,0,306.5C0,320,4,324,8.75,324c306.5,0,306.5,0,306.5,0\n		c4.75,0,8.75-4,8.75-8.75c0-306.5,0-306.5,0-306.5C324,4,320,0,315.25,0L315.25,0z M315.25,315.25c-306.5,0-306.5,0-306.5,0\n		c0-306.5,0-306.5,0-306.5c306.5,0,306.5,0,306.5,0V315.25z M306.5,17.5c-289,0-289,0-289,0c0,289,0,289,0,289c289,0,289,0,289,0\n		V17.5z M239.75,112.5c-32,17.75-32,17.75-32,17.75c-15-24.5-15-24.5-15-24.5l0,0c-1.25-2-3.25-3.5-5.5-4c-18-5-18-5-18-5\n		c-1-0.25-1.75-0.5-2.5-0.5l0,0c-37.75,0-37.75,0-37.75,0c-4.25,0-7.75,3-9,6.75v0.25c-12.75,45-12.75,45-12.75,45\n		C106,153.25,109,158.5,114,160c4.75,1.25,10-1.5,11.5-6.5c10.75-38.5,10.75-38.5,10.75-38.5c18,0,18,0,18,0\n		c-11.75,42.5-11.75,42.5-11.75,42.5l0,0c-16,56.25-16,56.25-16,56.25c-39.75,0-39.75,0-39.75,0c-5.25,0-9.5,4.25-9.5,9.5\n		s4.25,9.25,9.5,9.25c47,0,47,0,47,0l0,0c4,0,7.75-2.75,9-6.75C158,171.5,158,171.5,158,171.5c4.75,1.25,4.75,1.25,4.75,1.25\n		c23.5,54.5,23.5,54.5,23.5,54.5c0,45,0,45,0,45c0,5.25,4.25,9.25,9.5,9.25s9.25-4,9.25-9.25c0-47,0-47,0-47\n		c0-1.25-0.25-2.5-0.75-3.75c-24.75-57.25-24.75-57.25-24.75-57.25c8.5-30.5,8.5-30.5,8.5-30.5c8.5,14,8.5,14,8.5,14\n		c2.75,4,8,5.5,12.5,3.25l0,0c30.75-17,30.75-17,30.75-17c0,138.25,0,138.25,0,138.25C202.25,291,202.25,291,202.25,291\n		C60.5,291,60.5,291,60.5,291C98,272.25,98,272.25,98,272.25C98,241,98,241,98,241c-6.5,0-11.25,0-11.25,0c-4.75,0-9.25-2-12.5-5.25\n		C70.75,232.5,69,228,69,223.25c0-9.75,8-17.75,17.75-17.75c0,0,5,0,11.25,0c0-159.75,0-159.75,0-159.75c141.75,0,141.75,0,141.75,0\n		V112.5z M186,96.5c9.25,0.5,16.75-6.5,17.25-15.75c0.25-9-6.75-16.75-15.75-17c-9.25-0.5-16.75,6.75-17.25,15.75\n		C170,88.5,177,96.25,186,96.5L186,96.5z\"/>\n</g>\n</svg>\n";

var stairsSymbol = "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<!-- Generator: Adobe Illustrator 14.0.0, SVG Export Plug-In . SVG Version: 6.00 Build 43363)  -->\n<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\" \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n<svg version=\"1.1\" id=\"Layer_1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" x=\"0px\" y=\"0px\"\n	 width=\"324px\" height=\"290px\" viewBox=\"0 0 324 290\" enable-background=\"new 0 0 324 290\" xml:space=\"preserve\">\n<rect id=\"background_fix\" fill=\"#ffffff\" stroke=\"none\" fill-opacity=\"0\" x=\"0\" y=\"0\" width=\"324\" height=\"290\" />\n<g>\n	<path d=\"M319.5,238.75L319.5,238.75c-128-221.5-128-221.5-128-221.5C185.5,6.75,174.25,0,162,0s-23.5,6.75-29.5,17.25\n		c-128,221.5-128,221.5-128,221.5c-6,10.5-6,23.5,0,34C10.75,283.25,22,290,34.25,290c255.5,0,255.5,0,255.5,0\n		c12.25,0,23.5-6.75,29.75-17.25C325.5,262.25,325.5,249.25,319.5,238.75L319.5,238.75z M300,261.75c-2,3.5-6,5.75-10.25,5.75\n		c-255.5,0-255.5,0-255.5,0c-4.25,0-8.25-2.25-10.25-5.75c-2.25-3.75-2.25-8.25,0-12c127.75-221.5,127.75-221.5,127.75-221.5\n		c2.25-3.5,6-5.75,10.25-5.75s8,2.25,10.25,5.75C300,249.75,300,249.75,300,249.75C302.25,253.5,302.25,258,300,261.75L300,261.75z\n		 M211,236.75c-22,0-22,0-22,0c0-12.25,0-12.25,0-12.25c-21.75,0-21.75,0-21.75,0c0-12.5,0-12.5,0-12.5c-22,0-22,0-22,0\n		c0-12.25,0-12.25,0-12.25c-22,0-22,0-22,0c0-12.25,0-12.25,0-12.25c-22,0-22,0-22,0c0-12.5,0-12.5,0-12.5c-21,0-21,0-21,0\n		c-3,5.25-3,5.25-3,5.25c18.75,0,18.75,0,18.75,0c0,12.25,0,12.25,0,12.25c22,0,22,0,22,0c0,12.5,0,12.5,0,12.5c22,0,22,0,22,0\n		c0,12.25,0,12.25,0,12.25c22,0,22,0,22,0c0,12.5,0,12.5,0,12.5c22,0,22,0,22,0c0,12.25,0,12.25,0,12.25c22,0,22,0,22,0\n		c0,12.25,0,12.25,0,12.25c24.5,0,24.5,0,24.5,0c0-5,0-5,0-5c-19.5,0-19.5,0-19.5,0V236.75z M150,144.25\n		c5.75,0,10.75-4.75,10.75-10.75s-5-11-10.75-11c-6,0-11,5-11,11S144,144.25,150,144.25L150,144.25z M229.25,169.5L229.25,169.5\n		c-0.25-0.25-0.25-0.25-0.25-0.25l0,0c-1.25-2-3.75-3-6.25-2.5c-38,7.75-38,7.75-38,7.75c-14-24.5-14-24.5-14-24.5\n		c13.5-14.75,13.5-14.75,13.5-14.75c21.25-22.5,21.25-22.5,21.25-22.5c2.25-2.5,2-6.5-0.5-8.75s-6.25-2.25-8.75,0.25\n		c-21,22.75-21,22.75-21,22.75c-16,17.25-16,17.25-16,17.25c-7.75,4.5-7.75,4.5-7.75,4.5C132.25,144,132.25,144,132.25,144\n		C116,120.25,116,120.25,116,120.25c-1.75-2.75-5.75-3.5-8.5-1.5c-2.75,1.75-3.5,5.75-1.5,8.5c17.25,25.5,17.25,25.5,17.25,25.5l0,0\n		c1,1.25,2,2.25,3.5,2.5c21.5,5.5,21.5,5.5,21.5,5.5c17.25,29.75,17.25,29.75,17.25,29.75c0.5,0.75,1,1.25,1.5,1.75l0,0\n		c33.5,27.5,33.5,27.5,33.5,27.5l0,0c23.75,19.75,23.75,19.75,23.75,19.75c2.75,2,6.5,1.75,8.75-1c2-2.5,1.75-6.5-1-8.75\n		c-23.75-19.5-23.75-19.5-23.75-19.5l0,0c-26.5-21.75-26.5-21.75-26.5-21.75c2-1.25,2-1.25,2-1.25c37.5-7.5,37.5-7.5,37.5-7.5\n		c15.5,22,15.5,22,15.5,22c2,2.75,6,3.25,8.75,1.5c2.75-2,3.5-6,1.5-8.75L229.25,169.5z\"/>\n</g>\n</svg>\n";


/****************************************/
/*             Supply Setup             */
/****************************************/

Elly.setCanvasSize(21, 9);

/****************************************/
/*          Read Data Function          */
/****************************************/

function readData() {

    /* QA Variables:
    dataQA[0] = Serial Number
    dataQA[1] = Head1 heat, offset
    dataQA[2] = Head2 heat, offset
    dataQA[3] = Max Print Speed
    dataQA[4] = Ribbon1 SKU
    dataQA[5] = Ribbon2 SKU
    */

    var dataQA = ScriptHelper.getQAVariables();

    ribbon1     = dataQA[4];
    ribbon1Heat = dataQA[1];
    ribbon2     = dataQA[5];
    ribbon2Heat = dataQA[2];
    printSpeed  = dataQA[3];
    serialNum   = dataQA[0];

    var serialNumLength = serialNum.toString().length;
    for (var i = serialNumLength; i < 6; i++){
        serialNum = '0' + serialNum;
    }
}

/****************************************/
/*          Template Function           */
/****************************************/

function templateQA() {

    // Column 1
    Elly.addRichTextItem(descText, 0.29, 0.29, 0, true, 5.4, 3.27, 0, color1, 20);
    Elly.setSelectedItemTextFontSize(19);
    Elly.addTextItem("Ribbon 1 Type:\nRibbon 1 Darkness:\nRibbon 2 Type:\nRibbon 2 Darkness:\nSpeed:\nSerial Number:\nDate:", 0.28, 3.11, 0, true, 2.74, 2.12, false, color1);
    // Dynamic text
    Elly.addTextItem(ribbon1+"\n"+ribbon1Heat+"\n"+ribbon2+"\n"+ribbon2Heat+"\n"+printSpeed+"\n"+serialNum+"\n"+dateMDY, 3.05, 3.14, 0, true, 2.74, 1.98, false, color1);
    
    Elly.addSymbol('', 0.28, 5.29, 0, false, 5.03, 3.51, false, runSymbol, color1, color2);
    
    // column2
    Elly.addTextItem("TEST", 5.87, -1.11, 0, false, 9.26, 5.17, false, color1, 72, "_RomaType Toro", 1, 1);
    Elly.addTextItem(testText, 6.33, 2.94, 0, true, 8.71, 4.11, false, color1, 72);
    Elly.setSelectedItemTextFontSize(12);
    Elly.addTextItem("TEST", 7.82, 6.42, 0, false, 5.36, 2.91, false, color1, 72, '', 1);
    
    // column3
    Elly.addSymbol('', 15.41, 0.70, 0, false, 4.18, 3.86, false, stairsSymbol, color1, color2);
    Elly.addTextItem("1234567890", 15.33, 4.87, 0, false, 1.53, 0.42, false, color1);
    Elly.addTextItem("1234567890", 16.71, 4.78, 0, false, 1.73, 0.56, false, color1);
    Elly.addTextItem("12345", 18.37, 4.74, 0, false, 1.19, 0.59, false, color1);
    Elly.addTextItem("67890", 15.34, 5.61, 0, false, 1.19, 0.59, false, color1);
    Elly.addTextItem("1234567890", 16.39, 5.42, 0, false, 2.79, 0.91, false, color1);
    Elly.addTextItem("1", 19.00, 5.31, 0, false, 0.65, 1.04, false, color1);
    Elly.addTextItem("23456789!"+"\n"+"@#$%^&*()_", 15.25, 6.22, 0, false, 4.26, 1.91, false, color1);

    // BC
    Elly.addBarcodeItem(18.72, 2.29, 270, true, 3.19, 0.97, Elly.lstBarcode1DSymbols.BARCODE_CODE128, 0, "12345", '#000000');
    Elly.addBarcodeItem(18.72, 5.71, 270, true, 3.19, 0.97, Elly.lstBarcode1DSymbols.BARCODE_CODE128, 0, "12345", '#000000');

    Elly.selectAll();
    EditController.lockItems(true);
    Elly.deselectAll();
}

/****************************************/
/*          Template Creation           */
/****************************************/

readData();
templateQA();
